Package: metamedian
Type: Package
Title: Meta-Analysis of Medians
Version: 1.2.2
Authors@R: c(person("Sean", "McGrath", role = c("aut", "cre"), 
                     email = "sean.mcgrath514@gmail.com",
                     comment = c(ORCID = "0000-0002-7281-3516")),
              person("XiaoFei", "Zhao", role = c("aut"),
                      email = "xiaofei.zhao@mail.mcgill.ca"),
              person("Stephan", "Katzenschlager", role = c("aut"),
                      email = "Stephan.Katzenschlager@med.uni-heidelberg.de"),
              person("Omer", "Ozturk", role = c("aut"), 
                      email = "ozturk.4@osu.edu"),
              person("Renata", "Iskander", role = c("ctb")),
              person("Russell", "Steele", role = c("aut"),
                      email = "russell.steele@mcgill.ca"),
              person("Andrea", "Benedetti", role = c("aut"), 
                      email = "andrea.benedetti@mcgill.ca",
                      comment = c(ORCID = "0000-0002-8314-9497")))
Maintainer: Sean McGrath <sean.mcgrath514@gmail.com>
Description: Implements several methods to meta-analyze studies that report the 
    sample median of the outcome. The methods described by 
    McGrath et al. (2019) <doi:10.1002/sim.8013>, 
    Ozturk and Balakrishnan (2020) <doi:10.1002/sim.8738>, and 
    McGrath et al. (2020a) <doi:10.1002/bimj.201900036> can be 
    applied to directly meta-analyze the median or difference of medians between 
    groups. Additionally, a number of methods (e.g., McGrath et al. (2020b) 
    <doi:10.1177/0962280219889080>, Cai et al. (2021) 
    <doi:10.1177/09622802211047348>, and McGrath et al. (2023) 
    <doi:10.1177/09622802221139233>) are implemented to estimate 
    study-specific (difference of) means and their standard errors in order to 
    estimate the pooled (difference of) means. Methods for meta-analyzing median 
    survival times (McGrath et al. (2026) <doi:10.1002/sim.70533>) are 
    also implemented. See McGrath et al. (2024) <doi:10.1002/jrsm.1686> for a 
    detailed guide on using the package.
Imports: estmeansd, Hmisc, metaBLUE, metafor, stats
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
URL: https://github.com/stmcg/metamedian,
        https://doi.org/10.1002/jrsm.1686
BugReports: https://github.com/stmcg/metamedian/issues
Depends: R (>= 2.10)
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-18 21:32:31 UTC; Sean
Author: Sean McGrath [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7281-3516>),
  XiaoFei Zhao [aut],
  Stephan Katzenschlager [aut],
  Omer Ozturk [aut],
  Renata Iskander [ctb],
  Russell Steele [aut],
  Andrea Benedetti [aut] (ORCID: <https://orcid.org/0000-0002-8314-9497>)
Repository: CRAN
Date/Publication: 2026-04-18 21:50:02 UTC
Built: R 4.5.2; ; 2026-04-18 23:55:19 UTC; unix

Package: metamedian
Type: Package
Title: Meta-Analysis of Medians
Version: 1.2.2
Authors@R: c(person("Sean", "McGrath", role = c("aut", "cre"), 
                     email = "sean.mcgrath514@gmail.com",
                     comment = c(ORCID = "0000-0002-7281-3516")),
              person("XiaoFei", "Zhao", role = c("aut"),
                      email = "xiaofei.zhao@mail.mcgill.ca"),
              person("Stephan", "Katzenschlager", role = c("aut"),
                      email = "Stephan.Katzenschlager@med.uni-heidelberg.de"),
              person("Omer", "Ozturk", role = c("aut"), 
                      email = "ozturk.4@osu.edu"),
              person("Renata", "Iskander", role = c("ctb")),
              person("Russell", "Steele", role = c("aut"),
                      email = "russell.steele@mcgill.ca"),
              person("Andrea", "Benedetti", role = c("aut"), 
                      email = "andrea.benedetti@mcgill.ca",
                      comment = c(ORCID = "0000-0002-8314-9497")))
Maintainer: Sean McGrath <sean.mcgrath514@gmail.com>
Description: Implements several methods to meta-analyze studies that report the 
    sample median of the outcome. The methods described by 
    McGrath et al. (2019) <doi:10.1002/sim.8013>, 
    Ozturk and Balakrishnan (2020) <doi:10.1002/sim.8738>, and 
    McGrath et al. (2020a) <doi:10.1002/bimj.201900036> can be 
    applied to directly meta-analyze the median or difference of medians between 
    groups. Additionally, a number of methods (e.g., McGrath et al. (2020b) 
    <doi:10.1177/0962280219889080>, Cai et al. (2021) 
    <doi:10.1177/09622802211047348>, and McGrath et al. (2023) 
    <doi:10.1177/09622802221139233>) are implemented to estimate 
    study-specific (difference of) means and their standard errors in order to 
    estimate the pooled (difference of) means. Methods for meta-analyzing median 
    survival times (McGrath et al. (2026) <doi:10.1002/sim.70533>) are 
    also implemented. See McGrath et al. (2024) <doi:10.1002/jrsm.1686> for a 
    detailed guide on using the package.
Imports: estmeansd, Hmisc, metaBLUE, metafor, stats
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
URL: https://github.com/stmcg/metamedian,
        https://doi.org/10.1002/jrsm.1686
BugReports: https://github.com/stmcg/metamedian/issues
Depends: R (>= 2.10)
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-18 21:32:31 UTC; Sean
Author: Sean McGrath [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7281-3516>),
  XiaoFei Zhao [aut],
  Stephan Katzenschlager [aut],
  Omer Ozturk [aut],
  Renata Iskander [ctb],
  Russell Steele [aut],
  Andrea Benedetti [aut] (ORCID: <https://orcid.org/0000-0002-8314-9497>)
Repository: CRAN
Date/Publication: 2026-04-18 21:50:02 UTC
Built: R 4.6.0; ; 2026-04-29 21:37:47 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(print,describe_studies)
export(cd)
export(describe_studies)
export(metamean)
export(metamedian)
export(metamedian_survival)
export(pool.med)
export(qe)
export(qe.study.level)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# metamedian: Meta-Analysis of Medians

[![CRAN_Status_Badge](https://badges.cranchecks.info/worst/metamedian.svg)](https://cran.r-project.org/package=metamedian)
[![R-CMD-check](https://github.com/stmcg/metamedian/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/stmcg/metamedian/actions/workflows/R-CMD-check.yaml)
[![Codecov test
coverage](https://codecov.io/gh/stmcg/metamedian/graph/badge.svg)](https://app.codecov.io/gh/stmcg/metamedian)
[![CRAN_Download_Badge](https://cranlogs.r-pkg.org/badges/metamedian)](https://www.r-pkg.org/pkg/metamedian)
[![CRAN_Download_Badge_All](https://cranlogs.r-pkg.org/badges/grand-total/metamedian)](https://www.r-pkg.org/pkg/metamedian)

The `metamedian` package implements methods to meta-analyze studies that
report estimates of the median of the outcome of interest.

## Methods Included

### Median-Based Methods

This package implements several methods to directly meta-analyze studies
reporting sample medians. When the primary studies are one-group
studies, the methods of [McGrath et
al. (2019)](https://doi.org/10.1002/sim.8013) and [Ozturk and
Balakrishnan (2020)](https://doi.org/10.1002/sim.8738) can be applied to
estimate the pooled median. In the two-group context, the methods of
[McGrath et al. (2020a)](https://doi.org/10.1002/bimj.201900036) can be
applied to estimate the pooled difference of medians between groups.

The package also implements methods to meta-analyze median survival
times. The package can apply the methods described by [McGrath et
al. (2026)](https://doi.org/10.1002/sim.70533) to meta-analyze the
median survival time, difference of median survival times between
groups, and the ratio of median survival times between groups.

### Mean-Based Methods

These methods estimate the study-specific means and their standard
errors from studies reporting sample medians in order to estimate the
pooled (difference of) means. Specifically, one can apply the following
methods:

- [Hozo et al. (2005)](https://doi.org/10.1186/1471-2288-5-13)
- [Wan et al. (2014)](https://doi.org/10.1186/1471-2288-14-135)
- [Bland
  (2015)](https://lifescienceglobal.com/pms/index.php/ijsmr/article/view/2688)
- [Luo et al. (2018)](https://doi.org/10.1177/0962280216669183)
- [Shi et al. (2020a)](https://doi.org/10.1002/jrsm.1429)
- [Shi et
  al. (2020b)](https://www.intlpress.com/site/pub/pages/journals/items/sii/content/vols/0013/0004/a009/)
- [McGrath et al. (2020b)](https://doi.org/10.1177/0962280219889080)
- [Cai et al. (2021)](https://doi.org/10.1177/09622802211047348)
- [Yang et al. (2022)](https://doi.org/10.1080/02664763.2021.1967890)
- [McGrath et al. (2023)](https://doi.org/10.1177/09622802221139233)
- [Shi et al. (2023)](https://doi.org/10.1177/09622802231172043)

## Installation

You can install the released version of `metamedian` from CRAN with:

``` r
install.packages("metamedian")
```

After installing the `devtools` package (i.e., calling
`install.packages(devtools)`), the development version of `metamedian`
can be installed from GitHub with:

``` r
devtools::install_github("stmcg/metamedian")
```

## Usage

See [McGrath et al. (2024)](https://doi.org/10.1002/jrsm.1686) for a
detailed guide on using the `metamedian` package. Below, we include the
code used in the main examples in the paper. The examples are based on
the dataset `dat.age` included in the package.

Loading the package:

``` r
library(metamedian)
```

Setting a random number seed for reproducibility:

``` r
set.seed(1234)
```

### Descriptive Analyses

``` r
describe_studies(data = dat.age, group_labels = c ("Nonsurvivors", "Survivors"))
#> DESCRIPTION OF PRIMARY STUDIES
#>                                                       Nonsurvivors Survivors
#> N. studies:                                                     51        51
#> N. studies reporting the median:                                29        29
#>   N. studies reporting S1 (min, med, max, n):                    0         0
#>   N. studies reporting S2 (q1, med, q3, n):                     29        29
#>   N. studies reporting S3 (min, q1, med, q3, max, n):            0         0
#> N. studies reporting the mean:                                  22        22
#>   N. studies reporting the mean, sd, and n:                     22        22
#> Bowley skewness                                                             
#>   Minimum:                                                 -0.4000   -0.6000
#>   First quartile:                                          -0.0818   -0.1304
#>   Median:                                                   0.0000   -0.0526
#>   Mean:                                                    -0.0087   -0.0250
#>   Third quartile:                                           0.0909    0.1458
#>   Maximum:                                                  0.3846    0.4167
```

### Mean-Based Methods

The analyses below may take 5-10 minutes to run on a standard laptop.
For faster runtime, consider using fewer bootstrap replicates for the
QE, BC, and MLN methods.

``` r
res_wan <- metamean(dat.age, mean_method = "hozo/wan/bland")
res_luo <- metamean(dat.age, mean_method = "luo")
res_shi <- metamean(dat.age, mean_method = "shi_lognormal")
res_qe_mean <- metamean(dat.age, mean_method = "qe")
res_bc <- metamean(dat.age, mean_method = "bc")
res_mln <- metamean(dat.age, mean_method = "mln")
res_yang <- metamean(dat.age, mean_method = "yang")
```

The output of `res_mln` is illustrated below:

``` r
res_mln
#> 
#> Random-Effects Model (k = 51; tau^2 estimator: REML)
#> 
#> tau^2 (estimated amount of total heterogeneity): 28.0379 (SE = 7.0239)
#> tau (square root of estimated tau^2 value):      5.2951
#> I^2 (total heterogeneity / total variability):   86.72%
#> H^2 (total variability / sampling variability):  7.53
#> 
#> Test for Heterogeneity:
#> Q(df = 50) = 357.0967, p-val < .0001
#> 
#> Model Results:
#> 
#> estimate      se     zval    pval    ci.lb    ci.ub      
#>  12.8650  0.8342  15.4222  <.0001  11.2300  14.4999  *** 
#> 
#> ---
#> Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
```

### Median-Based Methods

``` r
res_mm <- metamedian(dat.age, median_method = "mm")
res_wm <- metamedian(dat.age, median_method = "wm")
res_qe_median <- metamedian(dat.age, median_method = "qe")
```

The output of `res_qe_median` is illustrated below:

``` r
res_qe_median
#> 
#> Random-Effects Model (k = 51; tau^2 estimator: REML)
#> 
#> tau^2 (estimated amount of total heterogeneity): 33.5585 (SE = 8.3883)
#> tau (square root of estimated tau^2 value):      5.7930
#> I^2 (total heterogeneity / total variability):   86.95%
#> H^2 (total variability / sampling variability):  7.66
#> 
#> Test for Heterogeneity:
#> Q(df = 50) = 373.6841, p-val < .0001
#> 
#> Model Results:
#> 
#> estimate      se     zval    pval    ci.lb    ci.ub      
#>  13.2238  0.9121  14.4980  <.0001  11.4361  15.0115  *** 
#> 
#> ---
#> Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
```

## Reference

To cite this package, use:

> McGrath S, Zhao X, Ozturk O, Katzenschlager S, Steele R, Benedetti A.
> metamedian: An R package for meta-analyzing studies reporting medians.
> *Research Synthesis Methods*. 2024; 15(2):332-346.
> <doi:10.1002/jrsm.1686>

For a BibTeX citation, use:

    @article{mcgrath2024metamedian,
      title={metamedian: An R package for meta-analyzing studies reporting medians},
      author={McGrath, Sean and Zhao, XiaoFei and Ozturk, Omer and Katzenschlager, Stephan and Steele, Russell and Benedetti, Andrea},
      journal={Research Synthesis Methods},
      volume={15},
      number={2},
      pages={332--346},
      year={2024},
      publisher={Wiley Online Library}
    }

#' Meta-Analysis of the (difference of) medians
#'
#' This function is a wrapper function for the \code{\link{qe}}, \code{\link{cd}}, and \code{\link{pool.med}} functions. The function implements the methods of McGrath et al. (2019), McGrath et al. (2020), and Ozturk and Balakrishnan (2020) to estimate the pooled (difference of) medians in a meta-analysis. Specifically, the function implements the (weighted) median of medians method, the Ozturk and Balakrishnan (2020) method, and the quantile matching estimation method to meta-analyze one-group studies; the function implements the (weighted) median of the difference of medians method and quantile matching estimation method to meta-analyze two-group studies.
#'
#' @param data data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
#' \tabular{ll}{
#' \code{min.g1} \tab minimum value. \cr
#' \code{q1.g1} \tab first quartile. \cr
#' \code{med.g1} \tab median. \cr
#' \code{q3.g1} \tab third quartile. \cr
#' \code{max.g1} \tab maximum value. \cr
#' \code{n.g1} \tab sample size. \cr
#' \code{mean.g1} \tab sample mean. \cr
#' \code{sd.g1} \tab sample standard deviation. \cr
#' \code{med.var.g1} \tab sampling variance of the median (only applicable when \code{median_method="cd"}). \cr
#' \code{med.ci.lb.g1} \tab lower confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
#' \code{med.ci.ub.g1} \tab upper confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
#' \code{alpha.1.g1} \tab \eqn{\alpha_1} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr
#' \code{alpha.2.g1} \tab \eqn{\alpha_2} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr}
#' For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{min.g2}, \code{q1.g2}, \code{med.g2}, \code{q3.g2}, \code{max.g2}, \code{n.g2}, \code{mean.g2}, and \code{sd.g2}.
#' @param median_method character string specifying the approach used to estimate the study-specific means and their standard errors. The options are
#' \tabular{ll}{
#' \code{"mm"} \tab Median of Medians (McGrath et al. 2019) for one-group studies and Median of the Difference of Medians (McGrath et al. 2020) for two group studies. \cr
#' \code{"wm"} \tab Weighted Median of Medians (McGrath et al. 2019) for one-group studies and Weighted Median of the Difference of Medians (McGrath et al. 2020) for two group studies. \cr
#' \code{"qe"} \tab Quantile Matching Estimation (McGrath et al. 2020). This approach is applicable for one-group studies or two-group studies. This is the default option. \cr
#' \code{"cd"} \tab Confidence Distribution (Ozturk and Balakrishnan 2020). This approach is applicable for one-group studies. \cr}
#' @param single.family (only applicable when \code{median_method} is set to \code{"qe"}) logical scalar indicating that for two-group studies, the parametric family of distributions is assumed to be the same across both groups. The default is \code{FALSE}. See 'Details' of \code{\link{qe.study.level}}.
#' @param loc.shift (only applicable when \code{median_method} is set to \code{"qe"}) logical scalar indicating that for two-group studies, distributions are assumed to only differ by a location shift. The default is \code{FALSE}. See 'Details' of \code{\link{qe.study.level}}.
#' @param norm.approx (only applicable when \code{median_method} is set to \code{"mm"} or \code{"wm"}) logical scalar indicating whether normality approximation of the binomial should be used to construct an approximate confidence interval. The default is \code{TRUE}.
#' @param coverage.prob (only applicable when \code{median_method} is set to \code{"mm"}, \code{"wm"}, or \code{"cd"}) numeric scalar indicating the desired coverage probability for the pooled (difference of medians) estimate. The default is \code{0.95}.
#' @param cd_method (only applicable when \code{median_method} is set to \code{"cd"}) character string specifying whether a fixed effect or random effects model is used. The options are \code{FE} (fixed effect) and \code{RE} (random effects). The default is \code{RE}.
#' @param pool_studies logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific outcome measure estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.
#' @param ... (only applicable when \code{median_method} is set to \code{"qe"}) optional arguments that are passed into the \code{\link[metafor]{rma.uni}} function for pooling. See documentation of \code{\link[metafor]{rma.uni}}.
#'
#' @return an object of class "rma.uni" (when \code{median_method} is set to \code{"qe"}) or a list (when \code{median_method} is set to \code{"mm"}, \code{"wm"}, or \code{"cd"}). For additional details, see \code{\link[metafor]{rma.uni}} (when \code{median_method} is set to \code{"qe"}), \code{\link{pool.med}} (when \code{median_method} is set to \code{"mm"} or \code{"wm"}), and \code{\link{cd}} (when \code{median_method} is set to \code{"cd"}).
#' @references McGrath S., Zhao X., Qin Z.Z., Steele R., and Benedetti A. (2019). One-sample aggregate data meta-analysis of medians. \emph{Statistics in Medicine}, \strong{38}, 969-984.
#' @references McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
#' @references McGrath S., Zhao X., Ozturk O., Katzenschlager S., Steele R., and Benedetti A. (2024). metamedian: An R package for meta-analyzing studies reporting medians. \emph{Research Synthesis Methods}, \strong{15}, 332-346.
#' @references Ozturk O. and Balakrishnan N. (2020). Meta‐analysis of quantile intervals from different studies with an application to a pulmonary tuberculosis data. \emph{Statistics in Medicine}, \strong{39}, 4519-4537.
#'
#' @examples
#' ## Quantile Matching Estimation method
#' metamedian(data = dat.age, median_method = "qe")
#'
#' ## Median of the Difference of Medians method
#' metamedian(data = dat.age, median_method = "mm")
#'
#' ## Weighted Median of the Difference of Medians method
#' metamedian(data = dat.age, median_method = "wm")
#'
#' @export

metamedian <- function(data, median_method = 'qe', single.family = FALSE,
                       loc.shift = FALSE, norm.approx = TRUE, coverage.prob = 0.95,
                       cd_method = 'RE', pool_studies = TRUE, ...) {
  df <- check_and_clean_df(df = data, method = median_method)
  if (!median_method %in% c('qe', 'mm', 'wm', 'cd')){
    stop("median_method must be set to 'mm', 'wm', 'qe', or 'cd'")
  }

  if (median_method == 'qe'){
    # QE method
    res <- qe(min.g1 = df$min.g1, q1.g1 = df$q1.g1, med.g1 = df$med.g1, q3.g1 = df$q3.g1, max.g1 = df$max.g1, n.g1 = df$n.g1, mean.g1 = df$mean.g1, sd.g1 = df$sd.g1,
              min.g2 = df$min.g2, q1.g2 = df$q1.g2, med.g2 = df$med.g2, q3.g2 = df$q3.g2, max.g2 = df$max.g2, n.g2 = df$n.g2, mean.g2 = df$mean.g2, sd.g2 = df$sd.g2,
              single.family = single.family, loc.shift = loc.shift, pool_studies = pool_studies, ...)
  } else if (median_method == 'cd') {
    res <- cd(q1 = df$q1.g1, med = df$med.g1, q3 = df$q3.g1, n = df$n.g1, mean = df$mean.g1, sd = df$sd.g1,
              med.var = df$med.var.g1, med.ci.lb = df$med.ci.lb.g1, med.ci.ub = df$med.ci.ub.g1,
              alpha.1 = df$alpha.1.g1, alpha.2 = df$alpha.2.g1, pooled.median.ci.level = coverage.prob,
              method = cd_method, pool_studies = pool_studies)
  } else {
    # MM and WM methods
    one_group <- all(is.na(df[, c('min.g2', 'q1.g2', 'med.g2', 'q3.g2', 'max.g2', 'n.g2', 'mean.g2', 'sd.g2')]))
    if (one_group){
      yi <- ifelse(!is.na(df$med.g1), df$med.g1, df$mean.g1)
      if (!pool_studies){
        return(list(yi = yi, sei = NULL))
      }
      if (median_method == 'wm'){
        wi <- df$n.g1
      }
    } else {
      yi <- ifelse(!is.na(df$med.g1), df$med.g1, df$mean.g1) -
        ifelse(!is.na(df$med.g2), df$med.g2, df$mean.g2)
      if (!pool_studies){
        return(list(yi = yi, sei = NULL))
      }
      if (median_method == 'wm'){
        wi <- df$n.g1 + df$n.g2
      }
    }
    if (median_method == 'mm'){
      res <- pool.med(yi = yi, norm.approx = norm.approx, coverage.prob = coverage.prob)
    } else if (median_method == 'wm'){
      res <- pool.med(yi = yi, wi = wi, norm.approx = norm.approx, coverage.prob = coverage.prob)
    }
  }
  return(res)
}

# Checking all methods for two-group studies
median_methods <- c('mm', 'wm', 'qe')
for (median_method in median_methods){
  test_that(paste0(median_method, " median method for two-group studies works"), {
    expect_no_error(metamedian(dat.age, median_method = median_method))
  })
}

# Checking all methods for one-group studies
median_methods_onegroup <- c('mm', 'wm', 'qe', 'cd')
for (median_method in median_methods_onegroup){
  test_that(paste0(median_method, " median method for one-group studies works"), {
    expect_no_error(metamedian(dat.age[, 1:7], median_method = median_method))
  })
}

#' Descriptive statistics for meta-analyzing studies reporting sample medians
#'
#' This function performs some descriptive analyses for meta-analyzing studies reporting sample medians. Specifically, this function describes: (i) the number of studies reporting various summary statistics, (ii) the Bowley skewness (Bowley, 1901) in the primary studies, and (iii) the results of a skewness test (Shi et al., 2023) applied to the summary statistics reported in the primary studies.
#'
#' @param data data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
#' \tabular{ll}{
#' \code{min.g1} \tab minimum value. \cr
#' \code{q1.g1} \tab first quartile. \cr
#' \code{med.g1} \tab median. \cr
#' \code{q3.g1} \tab third quartile. \cr
#' \code{max.g1} \tab maximum value. \cr
#' \code{n.g1} \tab sample size. \cr
#' \code{mean.g1} \tab sample mean. \cr
#' \code{sd.g1} \tab sample standard deviation. \cr
#' \code{med.var.g1} \tab sampling variance of the median (only applicable when \code{median_method="cd"}). \cr
#' \code{med.ci.lb.g1} \tab lower confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
#' \code{med.ci.ub.g1} \tab upper confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
#' \code{alpha.1.g1} \tab \eqn{\alpha_1} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr
#' \code{alpha.2.g1} \tab \eqn{\alpha_2} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr}
#' For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{min.g2}, \code{q1.g2}, \code{med.g2}, \code{q3.g2}, \code{max.g2}, \code{n.g2}, \code{mean.g2}, and \code{sd.g2}.
#' @param method character string specifying the sets of summary statistics to consider. If this argument is set to \code{"cd"}, the summary statistics for the CD method (see C1/C2, C3, C4, C5 in \code{\link{cd}}) are considered. Otherwise, the S1, S2, S3, and S4 summary statistics described in \code{\link{qe}} are considered.
#' @param group_labels vector of character strings specifying the names corresponding to groups 1 and 2, respectively. This argument is only applicable when the meta-analysis consists of two-group studies. By default, this argument is set to \code{c('Group 1', 'Group 2')}.
#' @return an object of class \code{"describe_studies"}. The object is a list with the following components:
#' \item{description}{data frame containing the results of the descriptive analyses.}
#' \item{bowley_g1}{vector containing the study-specific Bowley skewness values in group 1.}
#' \item{bowley_g2}{vector containing the study-specific Bowley skewness values in group 2.}
#' \item{skew_test_g1}{data frame containing the results of the skewness test of Shi et al. (2023) based on the group 1 data. The data frame contains the test statistic values, critical values at the 0.05 level, and indicators of statistical significance at the 0.05 level.}
#' \item{skew_test_g2}{data frame containing the results of the skewness test of Shi et al. (2023) based on the group 2 data. The data frame contains the test statistic values, critical values at the 0.05 level, and indicators of statistical significance at the 0.05 level.}
#' The results are printed with the \code{\link{print.describe_studies}} function.
#'
#' @references Bowley, A.L. (1901). Elements of Statistics. London: P.S. King & Son.
#' @references McGrath S., Zhao X., Ozturk O., Katzenschlager S., Steele R., and Benedetti A. (2024). metamedian: An R package for meta-analyzing studies reporting medians. \emph{Research Synthesis Methods}. \strong{15}(2):332-346.
#' @references Shi J., Luo D., Wan X., Yue L., Liu J., Bian Z., Tong T. (2023). Detecting the skewness of data from the five-number summary and its application in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{32}(7):1338-1360.
#'
#' @examples
#' describe_studies(data = dat.age, group_labels = c("Nonsurvivors", "Survivors"))
#'
#' @export
describe_studies <- function(data, method = 'qe',
                             group_labels = c('Group 1', 'Group 2')){
  df <- check_and_clean_df(df = data, method = method)
  n_studies <- nrow(df)

  if (length(method) != 1){
    stop("Argument 'method' must be of length 1")
  }
  if (method == 'cd'){
    one_group <- TRUE
  } else {
    g2_names <- c('min.g2', 'q1.g2', 'med.g2', 'q3.g2', 'max.g2', 'n.g2', 'mean.g2', 'sd.g2')
    one_group <- all(is.na(df[, g2_names]))
  }
  if (!one_group & length(group_labels) != 2){
    stop("Argument 'group_labels' must be of length 2")
  }

  scenario_g1 <- scenario_g2 <- rep(NA, times = n_studies)
  for (i in 1:n_studies){
    if (method != 'cd'){
      scenario_g1[i] <- tryCatch(get.scenario(df[i, 'min.g1'], df[i, 'q1.g1'], df[i, 'med.g1'], df[i, 'q3.g1'],
                                              df[i, 'max.g1'], df[i, 'mean.g1'], df[i, 'sd.g1']),
                                 error = function(e) NA)
    } else {
      scenario_g1[i] <- tryCatch(get.scenario.cd(df[i, 'q1.g1'], df[i, 'med.g1'], df[i, 'q3.g1'],
                                                 df[i, 'mean.g1'], df[i, 'sd.g1'], df[i, 'med.var.g1'],
                                                 df[i, 'med.ci.lb.g1'], df[i, 'med.ci.ub.g1'], df[i, 'alpha.1.g1'],
                                                 df[i, 'alpha.2.g1']),
                                 error = function(e) NA)
    }

    if (!one_group){
      scenario_g2[i] <- tryCatch(get.scenario(df[i, 'min.g2'], df[i, 'q1.g2'], df[i, 'med.g2'], df[i, 'q3.g2'],
                                              df[i, 'max.g2'], df[i, 'mean.g2'], df[i, 'sd.g2']),
                                 error = function (e) NA)
    }
  }
  df_g1_for_bowley <- df[!is.na(scenario_g1) & (scenario_g1 %in% c('S2', 'S3') | scenario_g1 == 'C5'), ]
  bowley_g1 <- (df_g1_for_bowley$q1.g1 - 2 * df_g1_for_bowley$med.g1 + df_g1_for_bowley$q3.g1) /
    (df_g1_for_bowley$q3.g1 - df_g1_for_bowley$q1.g1)
  skew_test_g1 <- perform_skew_test(df = df, group = 1, scenario = scenario_g1, n_studies = n_studies)

  if (!one_group){
    df_g2_for_bowley <- df[!is.na(scenario_g2) & (scenario_g2 %in% c('S2', 'S3') | scenario_g2 == 'C5'), ]
    bowley_g2 <- (df_g2_for_bowley$q1.g2 - 2 * df_g2_for_bowley$med.g2 + df_g2_for_bowley$q3.g2) /
      (df_g2_for_bowley$q3.g2 - df_g2_for_bowley$q1.g2)
    skew_test_g2 <- perform_skew_test(df = df, group = 1, scenario = scenario_g1, n_studies = n_studies)
  } else {
    bowley_g2 <- skew_test_g2 <-  NULL
  }

  if (one_group){
    ncols <- 1
  } else {
    ncols <- 2
  }

  # Bowley skewness descriptions
  description_bowley <- matrix(NA, nrow = 7, ncol = ncols)
  rownames(description_bowley) <- c('Bowley skewness', '  Minimum:', '  First quartile:',
                                    '  Median:', '  Mean:', '  Third quartile:', '  Maximum:')
  description_bowley['Bowley skewness', 1] <- ''
  description_bowley['  Minimum:', 1] <- myround(min(bowley_g1))
  description_bowley['  First quartile:', 1] <- myround(stats::quantile(bowley_g1, probs = 0.25))
  description_bowley['  Median:', 1] <- myround(stats::median(bowley_g1))
  description_bowley['  Mean:', 1] <- myround(mean(bowley_g1))
  description_bowley['  Third quartile:', 1] <- myround(stats::quantile(bowley_g1, probs = 0.75))
  description_bowley['  Maximum:', 1] <- myround(max(bowley_g1))
  if (!one_group){
    description_bowley['Bowley skewness', 2] <- ''
    description_bowley['  Minimum:', 2] <- myround(min(bowley_g2))
    description_bowley['  First quartile:', 2] <- myround(stats::quantile(bowley_g2, probs = 0.25))
    description_bowley['  Median:', 2] <- myround(stats::median(bowley_g2))
    description_bowley['  Mean:', 2] <- myround(mean(bowley_g2))
    description_bowley['  Third quartile:', 2] <- myround(stats::quantile(bowley_g2, probs = 0.75))
    description_bowley['  Maximum:', 2] <- myround(max(bowley_g2))
  }

  # Number of studies descriptions
  if (method == 'cd'){
    description <- matrix(NA, nrow = 7, ncol = ncols)
    rownames(description) <- c('N. studies:',
                               'N. studies reporting the median:',
                               '  N. studies reporting C1/C2 (med, CI bounds, coverage):',
                               '  N. studies reporting C3 (med, sampling variance):',
                               '  N. studies reporting C5 (q1, med, q3, n):',
                               'N. studies reporting the mean:',
                               '  N. studies reporting C4 (mean, sd, n):')
    description['N. studies:', 1] <- n_studies
    description['N. studies reporting the median:', 1] <- sum(!is.na(df$med.g1))
    description['  N. studies reporting C1/C2 (med, CI bounds, coverage):', 1] <- sum(scenario_g1 == 'C1', na.rm = TRUE)
    description['  N. studies reporting C3 (med, sampling variance):', 1] <- sum(scenario_g1 == 'C3', na.rm = TRUE)
    description['  N. studies reporting C5 (q1, med, q3, n):', 1] <- sum(scenario_g1 == 'C5', na.rm = TRUE)
    description['N. studies reporting the mean:', 1] <- sum(!is.na(df$mean.g1))
    description['  N. studies reporting C4 (mean, sd, n):', 1] <- sum(scenario_g1 == 'C4', na.rm = TRUE)

  } else {
    description <- matrix(NA, nrow = 7, ncol = ncols)
    rownames(description) <- c('N. studies:',
                               'N. studies reporting the median:',
                               '  N. studies reporting S1 (min, med, max, n):',
                               '  N. studies reporting S2 (q1, med, q3, n):',
                               '  N. studies reporting S3 (min, q1, med, q3, max, n):',
                               'N. studies reporting the mean:',
                               '  N. studies reporting the mean, sd, and n:')
    description['N. studies:', 1] <- n_studies
    description['N. studies reporting the median:', 1] <- sum(!is.na(df$med.g1))
    description['  N. studies reporting S1 (min, med, max, n):', 1] <- sum(scenario_g1 == 'S1', na.rm = TRUE)
    description['  N. studies reporting S2 (q1, med, q3, n):', 1] <- sum(scenario_g1 == 'S2', na.rm = TRUE)
    description['  N. studies reporting S3 (min, q1, med, q3, max, n):', 1] <- sum(scenario_g1 == 'S3', na.rm = TRUE)
    description['N. studies reporting the mean:', 1] <- sum(!is.na(df$mean.g1))
    description['  N. studies reporting the mean, sd, and n:', 1] <- sum(scenario_g1 == 'S4', na.rm = TRUE)
    if (!one_group){
      description['N. studies:', 2] <- n_studies
      description['N. studies reporting the median:', 2] <- sum(!is.na(df$med.g2))
      description['  N. studies reporting S1 (min, med, max, n):', 2] <- sum(scenario_g2 == 'S1', na.rm = TRUE)
      description['  N. studies reporting S2 (q1, med, q3, n):', 2] <- sum(scenario_g2 == 'S2', na.rm = TRUE)
      description['  N. studies reporting S3 (min, q1, med, q3, max, n):', 2] <- sum(scenario_g2 == 'S3', na.rm = TRUE)
      description['N. studies reporting the mean:', 2] <- sum(!is.na(df$mean.g2))
      description['  N. studies reporting the mean, sd, and n:', 2] <- sum(scenario_g2 == 'S4', na.rm = TRUE)
    }
  }

  description <- rbind(description, description_bowley)
  if (one_group){
    colnames(description) <- ' '
  } else {
    colnames(description) <- group_labels
  }

  output <- list(description = data.frame(description, check.names = FALSE),
                 bowley_g1 = bowley_g1, bowley_g2 = bowley_g2,
                 skew_test_g1 = skew_test_g1, skew_test_g2 = skew_test_g2)
  class(output) <- 'describe_studies'

  return(output)
}

perform_skew_test <- function(df, group, scenario, n_studies){
  res <- data.frame(
    test_stat = rep(NA, n_studies),
    critical_value = rep(NA, n_studies),
    reject = rep(NA, n_studies)
  )
  for (i in 1:n_studies){
    if (!is.na(scenario[i])){
      if (group == 1){
        n <- df[i, 'n.g1']
        min_val <- df[i, 'min.g1']
        q1_val <- df[i, 'q1.g1']
        med_val <- df[i, 'med.g1']
        q3_val <- df[i, 'q3.g1']
        max_val <- df[i, 'max.g1']
      } else if (group == 2){
        n <- df[i, 'n.g2']
        min_val <- df[i, 'min.g2']
        q1_val <- df[i, 'q1.g2']
        med_val <- df[i, 'med.g2']
        q3_val <- df[i, 'q3.g2']
        max_val <- df[i, 'max.g2']
      }

      if (scenario[i] == 'S1'){
        res[i, 'test_stat'] <- (min_val + max_val - 2 * med_val) / (max_val - min_val)
        res[i, 'critical_value'] <- 1 / log(n + 9) + 2.5 / (n + 1)
        res[i, 'reject'] <- abs(res[i, 'test_stat']) > res[i, 'critical_value']
      } else if (scenario[i] == 'S2'){
        res[i, 'test_stat'] <- (q1_val + q3_val - 2 * med_val) / (q3_val - q1_val)
        res[i, 'critical_value'] <- 2.65 / sqrt(n) - 6 / n^2
        res[i, 'reject'] <- abs(res[i, 'test_stat']) > res[i, 'critical_value']
      } else if (scenario[i] == 'S3'){
        T1 <- (min_val + max_val - 2 * med_val) / (max_val - min_val)
        T2 <- (q1_val + q3_val - 2 * med_val) / (q3_val - q1_val)
        res[i, 'test_stat'] <- max((2.65 * log(0.6 * n) / sqrt(n)) * abs(T1), T2)
        res[i, 'critical_value'] <- 3 / sqrt(n) - 40 / n^3
        res[i, 'reject'] <- abs(res[i, 'test_stat']) > res[i, 'critical_value']
      }
    }
  }
  return(res)
}

#' Print method for "describe_studies" objects
#'
#' Print method for objects of class "describe_studies"
#'
#' @param x object of class "describe_studies".
#' @param ... other arguments.
#' @return No value is returned.
#'
#' @seealso \code{\link{describe_studies}}
#'
#' @export
print.describe_studies <- function(x, ...){
  cat('DESCRIPTION OF PRIMARY STUDIES\n')
  print(x$description)
}

myround <- function(x){
  return(format(round(unname(x), 4), nsmall = 4))
}

# Checking methods other than the CD method
test_that("describe_studies with a method other than 'cd' works", {
  expect_no_error(describe_studies(dat.age))
})

# Checking the CD method
test_that("describe_studies with method 'cd' method works", {
  expect_no_error(describe_studies(dat.age[, 1:7], method = 'cd'))
})

#' Meta-Analysis of the median survival times
#'
#' This function implements the Wald approximation-based approach described by McGrath et al. (2026) to meta-analyze median survival times. This approach considers that each study reports a Kaplan-Meier estimate of median survival in (each group of) each study along with confidence intervals. This approach performs an inverse-variance weighted meta-analysis of the median survival time (for one group studies) or the difference/ratio of median survival times between groups (for two-group studies). The within-study standard errors are estimated by assuming the confidence intervals around the median survival estimates are Wald-type intervals.
#'
#' @param data data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
#' \tabular{ll}{
#' \code{med.g1} \tab median. \cr
#' \code{med.ci.lb.g1} \tab lower confidence interval bound around the median. \cr
#' \code{med.ci.ub.g1} \tab upper confidence interval bound around the median. \cr
#' \code{med.ci.level.g1} \tab level of the confidence interval}
#' For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{med.g2}, \code{med.ci.lb.g2}, \code{med.ci.ub.g2}, and \code{med.ci.level.g2}.
#' @param estimand character string specifying the estimand in the meta-analysis. The options are \code{"median_g1"} (median in group 1), \code{"median_g2"} (median in group 2), \code{"difference_median"} (difference of medians across groups), and \code{"ratio_median"} (ratio of medians across groups).
#' @param pool_studies logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific outcome measure estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.
#' @param ... optional arguments that are passed into the \code{\link[metafor]{rma.uni}} function for pooling. See documentation of \code{\link[metafor]{rma.uni}}.
#'
#' @return an object of class "rma.uni". For additional details, see \code{\link[metafor]{rma.uni}}.
#' @references McGrath S., Yang C.H., Kimmelman J., Ozturk O., Steele R., and Benedetti A. (2026). Meta-analysis of median survival times with inverse-variance weighting. \emph{Statistics in Medicine}, \strong{45}, e70533.
#'
#' @examples
#' ## Median survival in the comparator group
#' metamedian_survival(data = dat.lung, estimand = "median_g2")
#'
#' ## Difference of median survival
#' metamedian_survival(data = dat.lung, estimand = "difference_median")
#'
#' ## Ratio of median survival (logarithm scale)
#' metamedian_survival(data = dat.lung, estimand = "ratio_median")
#'
#' @export

metamedian_survival <- function(data, estimand, pool_studies = TRUE, ...) {
  df <- check_and_clean_df(df = data, method = 'wald')
  if (!missing(estimand)){
    if (!estimand %in% c('median_g1', 'median_g2', 'difference_median', 'ratio_median')){
      stop("estimand must be set to 'median_g1', 'median_g2', 'difference_median', or 'ratio_median'")
    }
  }

  n_studies <- nrow(df)
  yi <- vi <- rep(NA, length = n_studies)

  for (i in 1:n_studies){
    if (estimand != 'median_g2'){
      se_g1 <- se_median_survival_helper(est = df$med.g1[i],
                                         lb = df$med.ci.lb.g1[i],
                                         ub = df$med.ci.ub.g1[i],
                                         ci_level = df$med.ci.level.g1[i])
    }
    if (estimand != 'median_g1'){
      se_g2 <- se_median_survival_helper(est = df$med.g2[i],
                                         lb = df$med.ci.lb.g2[i],
                                         ub = df$med.ci.ub.g2[i],
                                         ci_level = df$med.ci.level.g2[i])
    }
    if (estimand == 'median_g1'){
      yi[i] <- df$med.g1[i]
      vi[i] <- se_g1^2
    } else if (estimand == 'median_g2'){
      yi[i] <- df$med.g2[i]
      vi[i] <- se_g2^2
    } else if (estimand == 'difference_median'){
      yi[i] <- df$med.g1[i] - df$med.g2[i]
      vi[i] <- se_g1^2 + se_g2^2
    } else if (estimand == 'ratio_median'){
      yi[i] <- log(df$med.g1[i]) - log(df$med.g2[i])
      vi[i] <- se_g1^2 / df$med.g1[i]^2 + se_g2^2 / df$med.g2[i]^2
    }
  }
  if (!pool_studies){
    res <- list(yi = yi, sei = sqrt(vi))
  } else {
    res <- metafor::rma.uni(yi = yi, vi = vi, ...)
  }

  return(res)
}

se_median_survival_helper <- function(est, lb, ub, ci_level){
  alpha <- (1 - ci_level)
  if (!is.na(ub)){
    return((ub - lb) / (2 * stats::qnorm(1 - alpha / 2)))
  } else {
    return((est - lb) / (stats::qnorm(1 - alpha / 2)))
  }
}

# Checking all methods for one-group studies
estimands <- c('median_g1', 'median_g2', 'difference_median', 'ratio_median')
for (estimand in estimands){
  test_that(paste0(estimand, " estimand for metamedian_survival works"), {
    expect_no_error(metamedian_survival(dat.lung, estimand = estimand))
  })
}

#' Meta-Analysis of the (difference of) means
#'
#' The function meta-analyzes one-group or two-group studies where each study reports one of the following summary measures: \itemize{
#' \item S1: median, minimum and maximum values, and sample size
#' \item S2: median, first and third quartiles, and sample size
#' \item S3: median, minimum and maximum values, first and third quartiles, and sample size
#' \item S4: mean, standard deviation, and sample size.
#'  }
#' This function estimates the study-specific means and their standard errors from the S1, S2, S3, or S4 summary data. When studies report S1, S2, or S3 summary data, a number of approaches can be applied to estimate the study-specific means and their standard errors. Then, this function estimates the pooled mean (for one-group studies) or the pooled difference of means (for two-group studies) based on the standard inverse variance method via the \code{\link[metafor]{rma.uni}} function. The convention used for calculating differences of means in two-group studies is: mean in group 1 minus mean in group 2.
#'
#' @param data data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
#' \tabular{ll}{
#' \code{min.g1} \tab minimum value. \cr
#' \code{q1.g1} \tab first quartile. \cr
#' \code{med.g1} \tab median. \cr
#' \code{q3.g1} \tab third quartile. \cr
#' \code{max.g1} \tab maximum value. \cr
#' \code{n.g1} \tab sample size. \cr
#' \code{mean.g1} \tab sample mean. \cr
#' \code{sd.g1} \tab sample standard deviation. \cr}
#' For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{min.g2}, \code{q1.g2}, \code{med.g2}, \code{q3.g2}, \code{max.g2}, \code{n.g2}, \code{mean.g2}, and \code{sd.g2}.
#' @param mean_method character string specifying the approach used to estimate the study-specific means. The options are the following:
#' \tabular{ll}{
#' \code{'hozo/wan/bland'} \tab Method recommended by Wan et al. (2014), i.e., the method of Hozo et al. (2005) in scenario S1, method of Wan et al. (2014) in scenario S2, and method of Bland (2015) in scenario S3. \cr
#' \code{'luo'} \tab Method of Luo et al. (2018). \cr
#' \code{'shi_lognormal'} \tab Method of Shi et al. (2020b). \cr
#' \code{'qe'} \tab Quantile Matching Estimation method (McGrath et al. 2020). \cr
#' \code{'bc'} \tab Box-Cox method (McGrath et al. 2020). \cr
#' \code{'mln'} \tab Method for Unknown Non-Normal Distributions (Cai et al. 2021). \cr
#' \code{'yang'} \tab Method of Yang et al. (2022) under the assumption of normality. \cr}
#' @param se_method character string specifying the approach used to estimate the standard errors of the study-specific means estimators in scenarios S1, S2, and S3. The options are the following:
#' \tabular{ll}{
#' \code{'naive'} \tab Uses the estimated standard deviation divided by the square root of the sample size as the estimate of the standard error of the mean estimator. This is the default option when \code{mean_method} is set to \code{'wan'}, \code{'luo'}, or \code{'shi_lognormal'}. The approach used to estimate the standard deviation is specified by the \code{sd_method} argument. \cr
#' \code{'bootstrap'} \tab Parametric bootstrap approach described by McGrath et al. (2023). This option is only available (and is the default option) when \code{mean_method} is set to \code{'qe'}, \code{'bc'}, or \code{'mln'}. \cr
#' \code{'plugin'} \tab Uses the analytically derived standard error of the mean estimator, and plugs in the estimated standard deviation in place of the distributional standard deviation. This option is only available (and is the default option) when \code{mean_method} is set to \code{'yang'}. \cr}
#' @param sd_method character string specifying the approach used to estimate the study-specific standard deviations when applying the naive standard error estimator (if applicable). The options are the following:
#' \tabular{ll}{
#' \code{'wan'} \tab Method of Wan et al. (2014). This is the default option when \code{mean_method} is set to \code{'hozo/wan/bland'}.\cr
#' \code{'wan/shi_normal'} \tab Method recommended by Shi et al. (2020a), i.e., the method of Wan et al. (2014) in scenarios S1 and S2 and the method of Shi et al. (2020a) in scenario S3. This is the default option when \code{mean_method} is set to \code{'luo'}. \cr
#' \code{'shi_lognormal'} \tab Method of Shi et al. (2020b). This is the default option when \code{mean_method} is set to \code{'shi_lognormal'}. \cr
#' \code{'qe'} \tab Quantile Matching Estimation method (McGrath et al. 2020). This is the default option when \code{mean_method} is set to \code{'qe'}. \cr
#' \code{'bc'} \tab Box-Cox method (McGrath et al. 2020). This is the default option when \code{mean_method} is set to \code{'bc'}. \cr
#' \code{'mln'} \tab Method for Unknown Non-Normal Distributions (Cai et al. 2021). This is the default option when \code{mean_method} is set to \code{'mln'}. \cr
#' \code{'yang'} \tab Method of Yang et al. (2022) under the assumption of normality. This is the default option when \code{mean_method} is set to \code{'yang'}. \cr}
#' @param nboot integer specifying the number of bootstrap samples to use when using parametric bootstrap to estimate the study-specific standard errors in scenarios S1, S2, and S3. The default is \code{1000}.
#' @param pool_studies logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific outcome measure estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.
#' @param ... optional arguments that are passed into the \code{\link[metafor]{rma.uni}} function for pooling. See documentation of \code{\link[metafor]{rma.uni}}.
#'
#' @return an object of class "rma.uni". See documentation of \code{\link[metafor]{rma.uni}}.
#' @references Bland M. (2015). Estimating mean and standard deviation from the sample size, three quartiles, minimum, and maximum. \emph{International Journal of Statistics in Medical Research}. \strong{4}(1):57-64.
#' @references Cai S., Zhou J., and Pan J. (2021). Estimating the sample mean and standard deviation from order statistics and sample size in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{30}(12):2701-2719.
#' @references Hozo S.P., Djulbegovic B., and Hozo I. (2005). Estimating the mean and variance from the median, range, and the size of a sample. \emph{BMC Medical Research Methodology}. \strong{5}(1):1-10.
#' @references Luo D., Wan X., Liu J., and Tong T. (2016). Optimally estimating the sample mean from the sample size, median, mid-range, and/or mid-quartile range. \emph{Statistical Methods in Medical Research}. \strong{27}(6):1785-805.
#' @references McGrath S., Zhao X., Steele R., Thombs B.D., Benedetti A., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2020). Estimating the sample mean and standard deviation from commonly reported quantiles in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{29}(9):2520-2537.
#' @references McGrath S., Katzenschlager S., Zimmer A.J., Seitel A., Steele R., and Benedetti A. (2023). Standard error estimation in meta-analysis of studies reporting medians. \emph{Statistical Methods in Medical Research}. \strong{32}(2):373-388.
#' @references McGrath S., Zhao X., Ozturk O., Katzenschlager S., Steele R., and Benedetti A. (2024). metamedian: An R package for meta-analyzing studies reporting medians. \emph{Research Synthesis Methods}. \strong{15}(2):332-346.
#' @references Shi J., Luo D., Weng H., Zeng X.T., Lin L., Chu H., and Tong T. (2020a). Optimally estimating the sample standard deviation from the five-number summary. \emph{Research synthesis methods}. \strong{11}(5):641-654.
#' @references Shi J., Tong T., Wang Y., and Genton M.G. (2020b). Estimating the mean and variance from the five-number summary of a log-normal distribution. \emph{Statistics and Its Interface}. \strong{13}(4):519-531.
#' @references Wan X., Wang W., Liu J., and Tong T. (2014). Estimating the sample mean and standard deviation from the sample size, median, range and/or interquartile range. \emph{BMC Medical Research Methodology}. \strong{14}(1):1-13.
#' @references Yang X., Hutson A.D., and Wang D. (2022). A generalized BLUE approach for combining location and scale information in a meta-analysis. \emph{Journal of Applied Statistics}. \strong{49}(15):3846-3867.
#'
#' @examples
#' \donttest{
#'
#' ## Method for Unknown Non-Normal Distributions
#' metamean(data = dat.age, mean_method = "mln", se_method = "bootstrap", nboot = 50)
#'
#' ## Box-Cox method
#' metamean(data = dat.age, mean_method = "bc", se_method = "bootstrap", nboot = 50)
#'
#' ## Quantile Matching Estimation method
#' metamean(data = dat.age, mean_method = "qe", se_method = "bootstrap", nboot = 50)
#'
#' }
#'
#' @export

metamean <- function(data, mean_method = 'mln', se_method,
                     sd_method, nboot = 1e3, pool_studies = TRUE, ...) {

  df <- check_and_clean_df(df = data, method = mean_method)
  n_studies <- nrow(df)

  res <- check_mean_se_methods(mean_method = mean_method, se_method = se_method,
                               sd_method = sd_method, n = n_studies)
  mean_method <- res$mean_method
  se_method <- res$se_method
  sd_method <- res$sd_method

  one_group <- all(is.na(df[, c('min.g2', 'q1.g2', 'med.g2', 'q3.g2', 'max.g2', 'n.g2', 'mean.g2', 'sd.g2')]))
  mean.g1 <- rep(NA, times = n_studies); mean.g2 <- rep(NA, times = n_studies)
  se.g1 <- rep(NA, times = n_studies); se.g2 <- rep(NA, times = n_studies)

  for (i in 1:n_studies){
    # Group 1 Analyses
    scenario.g1 <- get.scenario(df[i, 'min.g1'], df[i, 'q1.g1'], df[i, 'med.g1'], df[i, 'q3.g1'], df[i, 'max.g1'],
                                df[i, 'mean.g1'], df[i, 'sd.g1'])
    if (scenario.g1 == 'S4'){
      mean.g1[i] <- df[i, 'mean.g1']
      se.g1[i] <- df[i, 'sd.g1'] / sqrt(df[i, 'n.g1'])
    } else {
      res <- get_mean_se(df = df[i, ], mean_method = mean_method[i], se_method = se_method[i],
                         sd_method = sd_method[i], scenario = scenario.g1, group = 1, nboot = nboot)
      mean.g1[i] <- res$est.mean
      se.g1[i] <- res$est.se

    }

    # Group 2 Analyses
    if (!one_group){
      scenario.g2 <- get.scenario(df[i, 'min.g2'], df[i, 'q1.g2'], df[i, 'med.g2'], df[i, 'q3.g2'], df[i, 'max.g2'],
                                  df[i, 'mean.g2'], df[i, 'sd.g2'])
      if (scenario.g2 == 'S4'){
        mean.g2[i] <- df[i, 'mean.g2']
        se.g2[i] <- df[i, 'sd.g2'] / sqrt(df[i, 'n.g2'])
      } else {
        res <- get_mean_se(df = df[i, ], mean_method = mean_method[i], se_method = se_method[i],
                           sd_method = sd_method[i], scenario = scenario.g2, group = 2, nboot = nboot)
        mean.g2[i] <- res$est.mean
        se.g2[i] <- res$est.se
      }
    }
  }
  if (one_group){
    yi <- mean.g1
    sei <- se.g1
  } else {
    yi <- mean.g1 - mean.g2
    sei <- sqrt(se.g1^2 + se.g2^2)
  }
  if (pool_studies){
    return(metafor::rma.uni(yi = yi, sei = sei, ...))
  } else {
    return(list(yi = yi, sei = sei))
  }
}

check_and_clean_df <- function(df, method){
  if (!is.data.frame(df)){
    stop("'data' must be of class data.frame")
  } else {
    if ("tbl_df" %in% class(df)) {
      df <- as.data.frame(df)
    }
  }
  if (length(method) == 1 && method == 'cd'){
    all_possible_colnames <- c('q1.g1', 'med.g1', 'q3.g1', 'n.g1', 'mean.g1', 'sd.g1', 'med.var.g1',
                               'med.ci.lb.g1', 'med.ci.ub.g1', 'alpha.1.g1', 'alpha.2.g1')
    if (any(c('min.g2', 'q1.g2', 'med.g2', 'q3.g2', 'max.g2', 'n.g2', 'mean.g2', 'sd.g2') %in% colnames(df))){
      warning('A data set with two groups was provided, but the CD method is only applicable for one-group studies. The CD method is only meta-analyzing the group 1 data.')
    }
  } else if (length(method) == 1 && method == 'wald') {
    all_possible_colnames <- c('med.g1', 'med.ci.lb.g1', 'med.ci.ub.g1', 'med.ci.level.g1',
                               'med.g2', 'med.ci.lb.g2', 'med.ci.ub.g2', 'med.ci.level.g2')
  } else {
    all_possible_colnames <- c('min.g1', 'q1.g1', 'med.g1', 'q3.g1', 'max.g1', 'n.g1', 'mean.g1', 'sd.g1',
                               'min.g2', 'q1.g2', 'med.g2', 'q3.g2', 'max.g2', 'n.g2', 'mean.g2', 'sd.g2')
  }

  # Filling missing columns
  missing_cols <- all_possible_colnames[which(!all_possible_colnames %in% colnames(df))]
  df[, missing_cols] <- NA

  # Checking class of summary data
  for (col in all_possible_colnames){
    if (!class(df[, col]) %in% c('numeric', 'integer')){
      if (class(df[, col]) %in% 'logical' | all(is.na(df[, col]))){
        next()
      }
      stop('Summary data must be of class numeric or integer. Column ', col, ' is not of one of these classes')
    }
  }

  # Removing any empty rows
  temp <- df[, all_possible_colnames]
  na.row.indicator <- apply(temp, 1, function(x) all(is.na(x)))
  if (any(na.row.indicator)) {
    if (all(na.row.indicator)){
      stop(paste0('All rows in the input data set have all summary data set to NA. This may be due to the column names of the input data set being set incorrectly.'))
    } else {
      stop(paste0('The following rows in the input data set have all summary data set to NA: ',
                  paste(which(na.row.indicator), collapse = ' ')))
    }
  }

  return(df)
}

check_mean_se_methods <- function(mean_method, se_method, sd_method, n){
  if (length(mean_method) == 1){
    mean_method <- rep(mean_method, times = n)
  } else {
    if (length(mean_method) != n){
      stop("The length of 'mean_method' must equal 1 or the number of rows in 'data'.")
    }
  }
  if (missing(se_method)){
    se_method <- rep(NA, times = n)
    for (i in 1:n){
      if (mean_method[i] %in% c('qe', 'bc', 'mln')){
        se_method[i] <- 'bootstrap'
      } else if (mean_method[i] == 'yang'){
        se_method[i] <- 'plugin'
      } else {
        se_method[i] <- 'naive'
      }
    }
  } else if (length(se_method) == 1){
    se_method <- rep(se_method, times = n)
  } else if (length(se_method) != n){
    stop("The length of 'se_method' must equal 1 or the number of rows in 'data'.")
  }

  if (missing(sd_method)){
    sd_method <- rep(NA, times = n)
    for (i in 1:n){
      if (se_method[i] == 'naive'){
        if (mean_method[i] %in% c('shi_lognormal', 'qe', 'bc', 'mln', 'yang')){
          sd_method[i] <- mean_method[i]
        } else if (mean_method[i] == 'luo'){
          sd_method[i] <- 'wan/shi_normal'
        } else if (mean_method[i] == 'hozo/wan/bland'){
          sd_method[i] <- 'wan'
        }
      }
    }
  } else if (length(sd_method) == 1){
    sd_method <- rep(sd_method, times = n)
  } else if (length(sd_method) != n){
    stop("The length of 'sd_method' must equal 1 or the number of rows in 'data'.")
  }

  # Checking that mean_method, se_method, and sd_method are set to valid options
  all_mean_methods <- c('qe', 'bc', 'mln', 'hozo/wan/bland', 'luo', 'yang', 'shi_lognormal')
  if (!all(mean_method %in% all_mean_methods)){
    if (any(mean_method == 'wan')){
      stop("The 'wan' option for mean_method has been renamed to 'hozo/wan/bland'. Please use the 'hozo/wan/bland' option instead.")
    } else if (any(mean_method == 'shi_normal')){
      stop("The 'shi_normal' option for mean_method has been removed because it was redundant with the 'luo' option. Please use the 'luo' option instead.")
    }
    stop("mean_method must be set to 'qe', 'bc', 'mln', 'hozo/wan/bland', 'luo', 'yang', or 'shi_lognormal'")
  }
  all_se_methods <- c('bootstrap', 'plugin', 'naive')
  if (!all(se_method %in% all_se_methods)){
    stop("se_method must be set to 'bootstrap', 'plugin', or 'naive'")
  }
  all_sd_methods <- c('qe', 'bc', 'mln', 'wan', 'yang', 'wan/shi_normal', 'shi_lognormal')
  if (!all(is.na(sd_method) | sd_method %in% all_sd_methods)){
    if (any(!is.na(sd_method) & sd_method == 'shi_normal')){
      stop("The 'shi_normal' option for sd_method has been renamed to 'wan/shi_normal'. Please use the 'wan/shi_normal' option instead.")
    }
    stop("sd_method must be set to 'qe', 'bc', 'mln', 'wan', 'yang', 'wan/shi_normal', or 'shi_lognormal'")
  }

  # Checking consistency between mean_method, sd_method, and se_method
  for (i in 1:n){
    if (se_method[i] == 'bootstrap'){
      if (!mean_method[i] %in% c('qe', 'bc', 'mln')){
        stop("se_method can only be set to 'bootstrap' when mean_method is set to 'qe', 'bc', or 'mln'")
      }
    } else if (se_method[i] == 'plugin'){
      if (mean_method[i] != 'yang'){
        stop("se_method can only be set to 'plugin' when mean_method is set to 'yang'")
      }
    } else if (se_method[i] == 'naive'){
      if (is.na(sd_method[i])){
        stop("sd_method must be specified when se_method is set to 'naive'")
      }
    }
  }

  return(list(mean_method = mean_method, se_method = se_method, sd_method = sd_method))
}

get_mean_se <- function(df, mean_method, se_method, sd_method, scenario, group, nboot){
  min.val <- df[, paste0('min.g', group)]
  q1.val <- df[, paste0('q1.g', group)]
  med.val <- df[, paste0('med.g', group)]
  q3.val <- df[, paste0('q3.g', group)]
  max.val <- df[, paste0('max.g', group)]
  n <- df[, paste0('n.g', group)]

  if (mean_method %in% c('luo', 'yang', 'shi_lognormal') |
      (!is.na(sd_method) & sd_method %in% c('wan', 'yang', 'wan/shi_normal', 'shi_lognormal'))){
    if (scenario == 'S1'){
      quants <- c(min.val, med.val, max.val)
    } else if (scenario == 'S2'){
      quants <- c(q1.val, med.val, q3.val)
    } else if (scenario == 'S3'){
      quants <- c(min.val, q1.val, med.val, q3.val, max.val)
    }
    if (min(quants) <= 0){
      if (mean_method == 'shi_lognormal'){
        stop('The mean method ', mean_method, ' can only be used for positive data')
      }
      if (sd_method == 'shi_lognormal'){
        stop('The standard deviation method ', sd_method, ' can only be used for positive data')
      }
    }
  }

  if (mean_method == 'mln' | (!is.na(sd_method) & sd_method == 'mln')){
    if (check_negative(min.val = min.val, q1.val = q1.val, med.val = med.val, q3.val = q3.val, max.val = max.val, scenario = scenario)){
      stop('The mln method can only be used for positive data')
    }
    fit_mln <- estmeansd::mln.mean.sd(min.val = min.val, q1.val = q1.val, med.val = med.val, q3.val = q3.val, max.val = max.val, n = n)
    if (mean_method == 'mln'){
      est.mean <- fit_mln$est.mean
    }
  }
  if (mean_method == 'bc' | (!is.na(sd_method) & sd_method == 'bc')){
    if (check_negative(min.val = min.val, q1.val = q1.val, med.val = med.val, q3.val = q3.val, max.val = max.val, scenario = scenario)){
      stop('The bc method can only be used for positive data')
    }
    fit_bc <- estmeansd::bc.mean.sd(min.val = min.val, q1.val = q1.val, med.val = med.val, q3.val = q3.val, max.val = max.val, n = n)
    if (mean_method == 'bc'){
      est.mean <- fit_bc$est.mean
    }
  }
  if (mean_method == 'qe' | (!is.na(sd_method) & sd_method == 'qe')){
    fit_qe <- estmeansd::qe.mean.sd(min.val = min.val, q1.val = q1.val, med.val = med.val, q3.val = q3.val, max.val = max.val, n = n)
    if (mean_method == 'qe'){
      est.mean <- fit_qe$est.mean
    }
  }
  if (mean_method == 'yang' | (!is.na(sd_method) & sd_method == 'yang')){
    fit_yang <- metaBLUE::BLUE_s(X = quants, n = n, type = scenario)
    if (mean_method == 'yang'){
      est.mean <- fit_yang$muhat
    }
  }

  if (mean_method == 'luo'){
    est.mean <- metaBLUE::Luo.mean(X = quants, n = n, type = scenario)$muhat
  } else if (mean_method == 'hozo/wan/bland'){
    if (scenario == 'S1'){
      est.mean <- (min.val + 2 * med.val + max.val) / 4
    } else if (scenario == 'S2'){
      est.mean <- (q1.val + med.val + q3.val) / 3
    } else if (scenario == 'S3'){
      est.mean <- (min.val + 2 * q1.val + 2 * med.val + 2 * q3.val + max.val) / 8
    }
  } else if (mean_method == 'shi_lognormal'){
    muhat <- metaBLUE::Luo.mean(X = log(quants), n = n, type = scenario)$muhat
    if (scenario == 'S1'){
      xi <- 2 * stats::qnorm((n - 0.375) / (n + 0.25))
      sigma2hat1 <- ((log(max.val) - log(min.val)) / xi)^2 / (1.01 + 0.25 / (log(n))^2)
      sigma4hat1 <- ((log(max.val) - log(min.val)) / xi)^4 / (1 + 2.23 * (log(n))^(-2))
      est.mean <- exp(muhat + sigma2hat1 / 2) / (1 + 0.565 * sigma2hat1 / n + 0.37 * sigma4hat1 / n)
    } else if (scenario == 'S2'){
      eta <- 2 * stats::qnorm((0.75 * n - 0.125) / (n + 0.25))
      sigma2hat2 <- ((log(q3.val) - log(q1.val)) / eta)^2 / (1 + 1.58 / n)
      sigma4hat2 <- ((log(q3.val) - log(q1.val)) / eta)^4 / (1 + 19.2 / n^1.2)
      est.mean <- exp(muhat + sigma2hat2 / 2) / (1 + 0.57 * sigma2hat2 / n + 0.75 * sigma4hat2 / n)
    } else if (scenario == 'S3'){
      xi <- 2 * stats::qnorm((n - 0.375) / (n + 0.25))
      eta <- 2 * stats::qnorm((0.75 * n - 0.125) / (n + 0.25))
      w3 <- 1 / (1 + 0.07 * n^0.6)
      sigma2hat3 <- (w3 * ((log(max.val) - log(min.val)) / xi) + (1 - w3) * ((log(q3.val) - log(q1.val)) / eta))^2 /
        (1 + 0.28 / (log(n))^2)
      sigma4hat3 <- (w3 * ((log(max.val) - log(min.val)) / xi) + (1 - w3) * ((log(q3.val) - log(q1.val)) / eta))^4 /
        (1 + 3.93 / n)
      est.mean <- exp(muhat + sigma2hat3 / 2) / (1 + 0.405 * sigma2hat3 / n + 0.315 * sigma4hat3 / n)
    }
  }

  if (se_method == 'bootstrap'){
    if (mean_method == 'mln'){
      est.se <- estmeansd::get_SE(fit_mln, nboot = nboot)$est.se
    } else if (mean_method == 'bc'){
      est.se <- estmeansd::get_SE(fit_bc, nboot = nboot)$est.se
    } else if (mean_method == 'qe'){
      est.se <- estmeansd::get_SE(fit_qe, nboot = nboot)$est.se
    }
  } else if (se_method == 'plugin'){
    est.se <- sqrt(fit_yang$Var_mu)
  } else if (se_method == 'naive'){
    if (sd_method == 'mln'){
      est.se <- fit_mln$est.sd / sqrt(n)
    } else if (sd_method == 'bc'){
      est.se <- fit_bc$est.sd / sqrt(n)
    } else if (sd_method == 'qe'){
      est.se <- fit_qe$est.sd / sqrt(n)
    } else if (sd_method == 'yang'){
      est.se <- fit_yang$sigmahat / sqrt(n)
    }
    else if (sd_method == 'wan/shi_normal' & scenario == 'S3'){
      theta1 <- (2 + 0.14 * n^0.6) * stats::qnorm((n - 0.375) / (n + 0.25))
      theta2 <- (2 + 2 / (0.07 * n^0.6)) * stats::qnorm((0.75 * n - 0.125) / (n + 0.25))
      est.se <- ((max.val - min.val) / theta1 + (q3.val - q1.val) / theta2) / sqrt(n)
    } else if (sd_method %in% c('wan', 'wan/shi_normal')){
      est.se <- metaBLUE::Wan.std(X = quants, n = n, type = scenario)$sigmahat / sqrt(n)
    } else if (sd_method == 'shi_lognormal'){
      muhat <- metaBLUE::Luo.mean(X = log(quants), n = n, type = scenario)$muhat
      if (scenario == 'S1'){
        xi <- 2 * stats::qnorm((n - 0.375) / (n + 0.25))
        sigma2hat1 <- ((log(max.val) - log(min.val)) / xi)^2 / (1.01 + 0.25 / (log(n))^2)
        sigma4hat1 <- ((log(max.val) - log(min.val)) / xi)^4 / (1 + 2.23 * (log(n))^(-2))
        sigma2hat <- exp(2 * muhat + 2 * sigma2hat1) / (1 + 2.26 * sigma2hat1 / n + 5.92 * sigma4hat1 / n) -
          exp(2 * muhat + sigma2hat1) / (1 + 2.26 * sigma2hat1 / n + 1.48 * sigma4hat1 / n)
      } else if (scenario == 'S2'){
        eta <- 2 * stats::qnorm((0.75 * n - 0.125) / (n + 0.25))
        sigma2hat2 <- ((log(q3.val) - log(q1.val)) / eta)^2 / (1 + 1.58 / n)
        sigma4hat2 <- ((log(q3.val) - log(q1.val)) / eta)^4 / (1 + 19.2 / n^1.2)
        sigma2hat <- exp(2 * muhat + 2 * sigma2hat2) / (1 + 2.28 * sigma2hat2 / n + 12 * sigma4hat2 / n) -
          exp(2 * muhat + sigma2hat2) / (1 + 2.28 * sigma2hat2 / n + 3 * sigma4hat2 / n)
      } else if (scenario == 'S3'){
        xi <- 2 * stats::qnorm((n - 0.375) / (n + 0.25))
        eta <- 2 * stats::qnorm((0.75 * n - 0.125) / (n + 0.25))
        w3 <- 1 / (1 + 0.07 * n^0.6)
        sigma2hat3 <- (w3 * ((log(max.val) - log(min.val)) / xi) + (1 - w3) * ((log(q3.val) - log(q1.val)) / eta))^2 /
          (1 + 0.28 / (log(n))^2)
        sigma4hat3 <- (w3 * ((log(max.val) - log(min.val)) / xi) + (1 - w3) * ((log(q3.val) - log(q1.val)) / eta))^4 /
          (1 + 3.93 / n)
        sigma2hat <- exp(2 * muhat + 2 * sigma2hat3) / (1 + 1.62 * sigma2hat3 / n + 5.04 * sigma4hat3 / n) -
          exp(2 * muhat + sigma2hat3) / (1 + 1.62 * sigma2hat3 / n + 1.26 * sigma4hat3 / n)
      }
      est.se <- sqrt(sigma2hat / n)
    }
  }

  return(list(est.mean = est.mean, est.se = est.se))
}

check_negative <- function(min.val = NA, q1.val = NA, med.val = NA,
                           q3.val = NA, max.val = NA, scenario){
  if (scenario %in% c('S1', 'S3')){
    return(min.val <= 0)
  } else if (scenario == 'S2'){
    return(q1.val <= 0)
  }
}

# Augmenting dat.age with fake data to check scenarios S1 and S3
set.seed(1234)
n <- nrow(dat.age)
min.g1 <- runif(n, min = 25, max = min(dat.age$q1.g1, na.rm = TRUE))
min.g2 <- runif(n, min = 25, max = min(dat.age$q1.g2, na.rm = TRUE))
max.g1 <- runif(n, min = max(dat.age$q3.g1, na.rm = TRUE), max = 100)
max.g2 <- runif(n, min = max(dat.age$q3.g2, na.rm = TRUE), max = 100)
dat.age_S1 <- dat.age_S3 <- dat.age
dat.age_S1[, c('q1.g1', 'q3.g1', 'q1.g2', 'q3.g2')] <- NA
dat.age_S1[, c('min.g1', 'max.g1', 'min.g2', 'max.g2')] <-
  dat.age_S3[, c('min.g1', 'max.g1', 'min.g2', 'max.g2')] <-
  cbind(min.g1, max.g1, min.g2, max.g2)

# Checking all approaches with the naive SE estimator
mean_methods <- c('hozo/wan/bland', 'luo', 'shi_lognormal', 'qe', 'bc', 'mln', 'yang')
sd_methods <- c('wan', 'wan/shi_normal', 'shi_lognormal', 'qe', 'bc', 'mln', 'yang')
for (mean_method in mean_methods){
  for (sd_method in sd_methods){
    test_that(paste0(mean_method, " mean method with the naive SE estimator (with ", sd_method, " standard deviation method) in scenario S1 works"), {
      expect_no_error(metamean(dat.age_S1, mean_method = mean_method, se_method = 'naive', sd_method = sd_method))
    })
    test_that(paste0(mean_method, " mean method with the naive SE estimator (with ", sd_method, " standard deviation method) in scenario S2 works"), {
      expect_no_error(metamean(dat.age, mean_method = mean_method, se_method = 'naive', sd_method = sd_method))
    })
    test_that(paste0(mean_method, " mean method with the naive SE estimator (with ", sd_method, " standard deviation method) in scenario S3 works"), {
      expect_no_error(metamean(dat.age_S3, mean_method = mean_method, se_method = 'naive', sd_method = sd_method))
    })
  }
}

# Checking all approaches with the bootstrap SE estimator
set.seed(1234)
mean_methods_boot <- c('qe', 'bc', 'mln')
for (mean_method in mean_methods_boot){
  test_that(paste0(mean_method, " mean method with the bootstrap SE estimator in scenario S1 works"), {
    expect_no_error(metamean(dat.age_S1, mean_method = mean_method, se_method = 'bootstrap', nboot = 10))
  })
  test_that(paste0(mean_method, " mean method with the bootstrap SE estimator in scenario S2 works"), {
    expect_no_error(metamean(dat.age, mean_method = mean_method, se_method = 'bootstrap', nboot = 10))
  })
  test_that(paste0(mean_method, " mean method with the bootstrap SE estimator in scenario S3 works"), {
    expect_no_error(metamean(dat.age_S3, mean_method = mean_method, se_method = 'bootstrap', nboot = 10))
  })
}

# Checking the approach with the plugin SE estimator
test_that("yang mean method with the plug-in SE estimator in scenario S1 works", {
  expect_no_error(metamean(dat.age_S1, mean_method = 'yang', se_method = 'plugin'))
})
test_that("yang mean method with the plug-in SE estimator in scenario S2 works", {
  expect_no_error(metamean(dat.age, mean_method = 'yang', se_method = 'plugin'))
})
test_that("yang mean method with the plug-in SE estimator in scenario S3 works", {
  expect_no_error(metamean(dat.age_S3, mean_method = 'yang', se_method = 'plugin'))
})

#' Meta-Analysis via median of (the difference of) medians method
#'
#' This function meta-analyzes the study-specific effect sizes by applying the (weighted) median of medians method (McGrath et al., 2019) in one-sample contexts and the (weighted) median of the difference of median method (McGrath et al., 2020) in two-sample contexts.
#'
#' For one-group studies, authors may report the sample median or mean. If these measures are supplied for \code{yi} and weights are not provided for \code{wi}, the function implements the median of medians (MM) method (McGrath et al., 2019).
#'
#' For two-group studies, authors may report the difference of medians or the difference of means across both groups. If these measures are supplied for \code{yi} and weights are not provided for \code{wi}, the function implements the median of the difference of medians (MDM) method (McGrath et al., 2020).
#'
#' Analogous weighted versions of the MM and MDM methods can be applied when study-specific sample sizes are provided for \code{wi}.
#'
#' The confidence interval around the pooled estimate is constructed by inverting the sign test.
#'
#' @param yi vector of the study-specific effect sizes (e.g., the medians or the difference of medians)
#' @param wi optional vector of positive, study-specific weights (e.g., sample sizes)
#' @param norm.approx optional logical scalar indicating whether normality approximation of the binomial should be used to construct an approximate confidence interval (the default is \code{TRUE}).
#' @param coverage.prob optional numeric scalar indicating the desired coverage probability (the default is \code{0.95}).
#' @return A list with components
#' \item{pooled.est}{Pooled estimate}
#' \item{ci.lb}{Lower bound of confidence interval}
#' \item{ci.ub}{Upper bound of confidence interval}
#' \item{cov.level}{Theoretical coverage of the confidence interval around the pooled estimate. When \code{norm.approx} is set to \code{TRUE}, the theoretical coverage is the same as the value specified by \code{coverage.prob}. When \code{norm.approx} is set to \code{FALSE}, the theoretical coverage is set to the smallest possible value greater than the value specified by \code{coverage.prob}.}
#'
#' @references McGrath S., Zhao X., Qin Z.Z., Steele R., and Benedetti A. (2019). One-sample aggregate data meta-analysis of medians. \emph{Statistics in Medicine}, \strong{38}, 969-984.
#' @references McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
#'
#' @examples
#' ## Storing data (study-specific difference of medians)
#' yi <- c(5.23, 3.10, 0.50, 0.78, 3.48, 0.59, 2.20, 5.06, 4.00)
#'
#' ## Meta-analysis of the difference of medians
#' pool.med(yi)
#'
#' @export

pool.med <- function(yi, wi, norm.approx = TRUE, coverage.prob = 0.95) {
  if (missing(yi)) {
    stop("Need to specify yi argument")
  }
  if (!missing(wi)) {
    if (any(wi <= 0)) {
      stop("wi argument must only have positive elements")
    }
    if (length(yi) != length(wi)) {
      stop("Lengths of yi and wi arguments do not match")
    }
  }
  n <- length(yi)
  if (norm.approx) {
    cov.level <- coverage.prob
    prob <- min(0.5, stats::qnorm(0.5 * cov.level + 0.5) / (2 * sqrt(n)))
    prob.vec <- c(0.5 - prob, 0.5, 0.5 + prob)
    if (missing(wi)) {
      quantiles <- unname(stats::quantile(yi, probs = prob.vec))
    } else {
      quantiles <- unname(Hmisc::wtd.quantile(yi, weights = wi,
                                              probs = prob.vec))
    }
  } else {
    T.val.all <- 0:floor(n / 2)
    coverages <- 1 - 2 * stats::pbinom(T.val.all, n, 0.5)
    if (!any(coverages >= coverage.prob)){
      stop(paste0("Not enough studies for exact coverage greater than or equal",
                  " to ", coverage.prob, ". The highest possible value for ",
                  "exact coverage is ", coverages[1]))
    }
    cov.level <- min(coverages[coverages >= coverage.prob])
    ind <- which(coverages == cov.level)
    if (missing(wi)) {
      yi.sorted <- sort(yi)
      quantiles <- c(yi.sorted[ind], unname(stats::quantile(yi, probs = 0.5)),
                     yi.sorted[n - ind])
    } else {
      prob.vec <- c(ind / n, 0.5, (n - ind + 1) / n)
      quantiles <- unname(Hmisc::wtd.quantile(yi, weights = wi,
                                              probs = prob.vec))
    }
  }
  return(list(pooled.est = quantiles[2], ci.lb = quantiles[1],
              ci.ub = quantiles[3], cov.level = cov.level))
}

#' Meta-Analysis via the confidence distribution approach
#'
#' The function applies the confidence distribution (CD) approach of Ozturk and Balakrishnan (2020) to meta-analyze one-group studies where each study reports one of the following summary measures: \itemize{
#' \item C1 (and C2): lower and upper bounds of a confidence interval around the median, and coverage probability
#' \item C3: median, variance estimate of the median, and sample size
#' \item C4: mean, standard deviation, and sample size.
#' \item C5: median, first and third quartiles, and sample size
#'  }
#' The function estimates the pooled median.
#'
#' Letting \eqn{k} denote the number of studies, provide study-specific summary data as vectors of length \eqn{k}. If a study does not report a given summary measure (e.g., the minimum value), give a value of \code{NA} for the position in the relevant vector. If no studies report a given summary measure, a vector of only \code{NA} values need not be provided. See 'Examples' for appropriate use.
#'
#' @param q1 vector of study-specific sample first quartile values. See 'Details'.
#' @param med vector of study-specific sample median values. See 'Details'.
#' @param q3 vector of study-specific sample third quartile values. See 'Details'.
#' @param n vector of study-specific sample sizes. See 'Details'.
#' @param mean vector of study-specific sample mean values. See 'Details'.
#' @param sd vector of study-specific sample standard deviation values. See 'Details'.
#' @param med.var vector of study-specific estimates of the variance of the median. See 'Details'.
#' @param med.ci.lb vector of study-specific lower confidence interval bounds around the medians
#' @param med.ci.ub vector of study-specific upper confidence interval bounds around the medians
#' @param alpha.1 vector of the study-specific \eqn{\alpha_1} values from Ozturk and Balakrishnan (2020)
#' @param alpha.2 vector of the study-specific \eqn{\alpha_2} values from Ozturk and Balakrishnan (2020)
#' @param pooled.median.ci.level optional numeric scalar indicating the desired coverage probability for the pooled median estimate. The default is \code{0.95}.
#' @param method character string specifying whether a fixed effect or random effects model is used. The options are \code{FE} (fixed effect) and \code{RE} (random effects). The default is \code{RE}.
#' @param pool_studies logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific effect size estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.
#'
#' @return A list with components
#' \item{pooled.est}{Pooled estimate of the median}
#' \item{pooled.est.var}{Estimated variance of the pooled median estimator}
#' \item{pooled.est.ci.lb}{Lower bound of confidence interval for the pooled median}
#' \item{pooled.est.ci.ub}{Upper bound of confidence interval for the pooled median}
#' \item{tausq.est}{Estimate of between-study variance (applicable only when \code{method} is set to \code{RE})}
#' \item{yi}{Study-specific point estimates}
#' \item{vi}{Study-specific sampling variances}
#'
#' @references Ozturk, O. and Balakrishnan N. (2020). Meta‐analysis of quantile intervals from different studies with an application to a pulmonary tuberculosis data. \emph{Statistics in Medicine}, \strong{39}, 4519-4537.
#'
#' @examples
#' ## Example 1:
#' med.vals <- c(6.1, 5.2, 3.1, 2.8, 4.5)
#' q1.vals <- c(2.0, 1.6, 2.6, 0.9, 3.2)
#' q3.vals <- c(10.2, 13.0, 8.3, 8.2, 9.9)
#' n.vals <- c(100, 92, 221, 81, 42)
#'
#' ## Meta-analyze studies via CD method
#' cd(q1 = q1.vals, med = med.vals, q3 = q3.vals, n = n.vals)
#'
#'
#' @export

cd <- function(q1, med, q3, n, mean, sd, med.var, med.ci.lb, med.ci.ub,
               alpha.1, alpha.2, pooled.median.ci.level = 0.95, method = 'RE',
               pool_studies = FALSE) {
  all.data.args.names <- c("q1", "med", "q3", "n", "mean",
                           "sd", "med.var", "med.ci.lb", "med.ci.ub", "alpha.1",
                           "alpha.2")

  all.args <- as.list(environment())
  data.args <- all.args[names(all.args) %in% all.data.args.names]
  data.args.spec <- data.args[sapply(data.args,
                                     function(x) class(x) == "numeric" |
                                       class(x) == "integer")]
  data.args.unspec.names <- all.data.args.names[!(all.data.args.names
                                                  %in% names(data.args.spec))]

  if (length(unique(lengths(data.args.spec))) != 1) {
    stop("All vectors of summary data must have same length")
  }

  df <- as.data.frame(data.args.spec)
  df[, data.args.unspec.names] <- rep(NA, nrow(df))
  na.row.indicator <- apply(df, 1, function(x) all(is.na(x)))
  if (any(na.row.indicator)) {
    df <- df[!na.row.indicator, ]
  }

  n_studies <- nrow(df)
  if (n_studies < 1L) {
    stop("No studies with non-missing summary data.")
  }
  alpha <- 1 - pooled.median.ci.level
  yi <- vi <- rep(NA, length = n_studies)

  for (i in 1:n_studies){
    scenario <- get.scenario.cd(q1 = df$q1[i], med = df$med[i], q3 = df$q3[i], mean = df$mean[i], sd = df$sd[i],
                                med.var = df$med.var[i], med.ci.lb = df$med.ci.lb[i], med.ci.ub = df$med.ci.ub[i],
                                alpha.1 = df$alpha.1[i], alpha.2 = df$alpha.2[i])

    if (scenario == 'C1'){
      zl <- stats::qnorm(df$alpha.1[i])
      zu <- stats::qnorm(1 - df$alpha.2[i])
      vi[i] <- (df$med.ci.ub[i] - df$med.ci.lb[i])^2 / (zu - zl)^2
      yi[i] <- (df$med.ci.lb[i] + df$med.ci.ub[i]) / 2 - (zl + zu) * sqrt(vi[i]) / 2
    } else if (scenario == 'C3'){
      yi[i] <- df$med[i]
      vi[i] <- df$med.var[i]
    } else if (scenario == 'C4'){
      yi[i] <- df$mean[i]
      vi[i] <- df$sd[i]^2 / df$n[i]
    } else if (scenario == 'C5'){
      yi[i] <- df$med[i]
      rr <- round(df$n[i] * 0.25, digits = 0)
      ss <- round(df$n[i] * 0.75, digits = 0)
      zl <- (rr - df$n[i] * 0.5 - 0.5) / sqrt(df$n[i] * 0.5^2)
      zu <- (ss - df$n[i] * 0.5 - 0.5) / sqrt(df$n[i] * 0.5^2)
      vi[i] <- (df$q3[i] - df$q1[i])^2 / (zu - zl)^2
    }
  }

  if (pool_studies){
    pooled_est_FE <- stats::weighted.mean(x = yi, w = 1 / vi)
    if (method == 'FE'){
      pooled_est <- pooled_est_FE
      pooled_est_var <- Jacknife(yi, vi, pooled_est)
      tausq_est <- NULL
    } else if (method == 'RE'){
      Q <- sum((yi - pooled_est_FE)^2 / vi)  # computation of Q^2 in section  3 of the paper
      A1 <- sum(1 / vi)
      C <- A1 - sum((1 / vi)^2) / A1
      tausq_est <- max((Q - (n_studies - 1)) / C, 0)
      pooled_est <- stats::weighted.mean(x = yi, w = 1 / (vi + tausq_est))
      pooled_est_var <- Jacknife(yi, vi + tausq_est, pooled_est)
    }

    ci.lb <- stats::qt(alpha / 2, n_studies - 1) * sqrt(pooled_est_var) + pooled_est
    ci.ub <- stats::qt(1 - alpha / 2, n_studies - 1) * sqrt(pooled_est_var) + pooled_est
    output <- list(pooled.est = pooled_est, pooled.est.var = pooled_est_var,
                   ci.lb = ci.lb, ci.ub = ci.ub, tausq.est = tausq_est,
                   yi = yi, vi = vi)
    return(output)
  } else {
    return(list(yi = yi, sei = sqrt(vi)))
  }

}

Jacknife <- function(yi, vi, pooled_est){
  n_studies <- length(yi)
  pooled_est_minusi <- rep(NA, n_studies)
  for (i in (1:n_studies)){
    pooled_est_minusi[i] <- stats::weighted.mean(yi[-i], 1 / vi[-i])
  }
  pi <- n_studies * pooled_est - (n_studies - 1) * pooled_est_minusi
  JVE <- sum((pi - mean(pi))^2) / ((n_studies - 1) * n_studies)
  return(JVE)
}

get.scenario.cd <- function(q1, med, q3, mean, sd, med.var, med.ci.lb, med.ci.ub,
                            alpha.1, alpha.2){
  if (!is.na(med.ci.lb) & !is.na(med.ci.ub) & !is.na(alpha.1) & !is.na(alpha.2)){
    return('C1')
  } else if (!is.na(med) & !is.na(med.var)){
    return('C3')
  } else if (!is.na(mean) & !is.na(sd)){
    return('C4')
  } else if (!is.na(med) & !is.na(q1) & !is.na(q3)){
    return('C5')
  } else {
    stop('Summary measures not in appropriate form. See documentation for
         appropriate forms for the CD approach.')
  }
}

get.fm <- function(x, family) {
  if (!(family %in% c("normal", "log-normal", "gamma", "weibull"))) {
    stop("family must be either normal, log-normal, gamma, or Weibull.")
  }
  if (family == "normal") {
    par <- x$norm.par
    fm <- stats::dnorm(stats::qnorm(0.5, par[1], par[2]), par[1], par[2])
  }
  else if (family == "log-normal") {
    par <- x$lnorm.par
    fm <- stats::dlnorm(stats::qlnorm(0.5, par[1], par[2]), par[1], par[2])
  }
  else if (family == "gamma") {
    par <- x$gamma.par
    fm <- stats::dgamma(stats::qgamma(0.5, par[1], par[2]), par[1], par[2])
  }
  else if (family == "weibull") {
    par <- x$weibull.par
    fm <- stats::dweibull(stats::qweibull(0.5, par[1], par[2]), par[1], par[2])
  }
  return(fm)
}

#' Example data set: Comparing the age between COVID-19 survivors and nonsurvivors (raw version)
#'
#' A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing the age of COVID-19 infected patients who died and those who survived. The unit of measurement for the age values is years. The rows in the data set correspond to the primary studies.
#'
#' @docType data
#'
#' @format A data frame with 52 rows and 13 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the journal name. \cr
#'   \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
#'   \code{q1.g1} \tab first quartile of age (nonsurvivor group). \cr
#'   \code{med.g1} \tab median age (nonsurvivor group). \cr
#'   \code{q3.g1} \tab third quartile of age (nonsurvivor group).\cr
#'   \code{mean.g1} \tab mean age (nonsurvivor group). \cr
#'   \code{sd.g1} \tab standard deviation of age (nonsurvivor group).\cr
#'   \code{n.g2} \tab number of subjects (survivor group). \cr
#'   \code{q1.g2} \tab first quartile of age (survivor group). \cr
#'   \code{med.g2} \tab median age (survivor group). \cr
#'   \code{q3.g2} \tab third quartile of age (survivor group).\cr
#'   \code{mean.g2} \tab mean age (survivor group). \cr
#'   \code{sd.g2} \tab standard deviation of age (survivor group).\cr}
#'
#' @references Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
#'
"dat.age_raw"


#' Example data set: Comparing the age between COVID-19 survivors and nonsurvivors (cleaned version)
#'
#' A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing the age of COVID-19 infected patients who died and those who survived. The unit of measurement for the age values is years. The rows in the data set correspond to the primary studies. Compared to the "raw" version (i.e., \code{\link{dat.age_raw}}), this data set excludes the primary study of Qi et al. (2021) due to its small sample size in the nonsurvivor group.
#'
#' @docType data
#'
#' @format A data frame with 51 rows and 13 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the journal name. \cr
#'   \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
#'   \code{q1.g1} \tab first quartile of age (nonsurvivor group). \cr
#'   \code{med.g1} \tab median age (nonsurvivor group). \cr
#'   \code{q3.g1} \tab third quartile of age (nonsurvivor group).\cr
#'   \code{mean.g1} \tab mean age (nonsurvivor group). \cr
#'   \code{sd.g1} \tab standard deviation of age (nonsurvivor group).\cr
#'   \code{n.g2} \tab number of subjects (survivor group). \cr
#'   \code{q1.g2} \tab first quartile of age (survivor group). \cr
#'   \code{med.g2} \tab median age (survivor group). \cr
#'   \code{q3.g2} \tab third quartile of age (survivor group).\cr
#'   \code{mean.g2} \tab mean age (survivor group). \cr
#'   \code{sd.g2} \tab standard deviation of age (survivor group).\cr}
#'
#' @references Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
#' @references Qi X., Liu Y., Wang J., Fallowfield J.A., Wang J., Li X., Shi J., Pan H., Zou S., Zhang H., and others. (2021). Clinical course and risk factors for mortality of COVID-19 patients with pre-existing cirrhosis: A multicentre cohort study, \emph{Gut}, \strong{70}, 433–436.
#'
"dat.age"


#' Example data set: Comparing aspartate transaminase levels between COVID-19 survivors and nonsurvivors (raw version)
#'
#' A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing aspartate transaminase (ASAT) levels of COVID-19 infected patients who died and those who survived. The unit of measurement for the ASAT levels is U/L. The rows in the data set correspond to the primary studies.
#'
#' @docType data
#'
#' @format A data frame with 27 rows and 13 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the journal name. \cr
#'   \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
#'   \code{q1.g1} \tab first quartile of the ASAT levels (nonsurvivor group). \cr
#'   \code{med.g1} \tab median ASAT level (nonsurvivor group). \cr
#'   \code{q3.g1} \tab third quartile of the ASAT levels (nonsurvivor group).\cr
#'   \code{mean.g1} \tab mean ASAT level (nonsurvivor group). \cr
#'   \code{sd.g1} \tab standard deviation of the ASAT levels (nonsurvivor group).\cr
#'   \code{n.g2} \tab number of subjects (survivor group). \cr
#'   \code{q1.g2} \tab first quartile of the ASAT levels (survivor group). \cr
#'   \code{med.g2} \tab median ASAT level (survivor group). \cr
#'   \code{q3.g2} \tab third quartile of the ASAT levels (survivor group).\cr
#'   \code{mean.g2} \tab mean ASAT level (survivor group). \cr
#'   \code{sd.g2} \tab standard deviation of the ASAT levels (survivor group).\cr}
#'
#' @references Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
#'
"dat.asat_raw"

#' Example data set: Comparing aspartate transaminase levels between COVID-19 survivors and nonsurvivors (cleaned version)
#'
#' A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing aspartate transaminase (ASAT) levels of COVID-19 infected patients who died and those who survived. The unit of measurement for the ASAT levels is U/L. The rows in the data set correspond to the primary studies. Compared to the "raw" version (i.e., \code{\link{dat.asat_raw}}), this data set excludes the primary study of Qi et al. (2021) due to its small sample size in the nonsurvivor group.
#'
#' @docType data
#'
#' @format A data frame with 26 rows and 13 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the journal name. \cr
#'   \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
#'   \code{q1.g1} \tab first quartile of the ASAT levels (nonsurvivor group). \cr
#'   \code{med.g1} \tab median ASAT level (nonsurvivor group). \cr
#'   \code{q3.g1} \tab third quartile of the ASAT levels (nonsurvivor group).\cr
#'   \code{mean.g1} \tab mean ASAT level (nonsurvivor group). \cr
#'   \code{sd.g1} \tab standard deviation of the ASAT levels (nonsurvivor group).\cr
#'   \code{n.g2} \tab number of subjects (survivor group). \cr
#'   \code{q1.g2} \tab first quartile of the ASAT levels (survivor group). \cr
#'   \code{med.g2} \tab median ASAT level (survivor group). \cr
#'   \code{q3.g2} \tab third quartile of the ASAT levels (survivor group).\cr
#'   \code{mean.g2} \tab mean ASAT level (survivor group). \cr
#'   \code{sd.g2} \tab standard deviation of the ASAT levels (survivor group).\cr}
#'
#' @references Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
#' @references Qi X., Liu Y., Wang J., Fallowfield J.A., Wang J., Li X., Shi J., Pan H., Zou S., Zhang H., and others. (2021). Clinical course and risk factors for mortality of COVID-19 patients with pre-existing cirrhosis: A multicentre cohort study, \emph{Gut}, \strong{70}, 433–436.
#'
"dat.asat"


#' Example data set: Comparing creatine kinase transaminase levels between COVID-19 survivors and nonsurvivors (raw version)
#'
#' A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing creatine kinase (CK) levels of COVID-19 infected patients who died and those who survived. The unit of measurement for the CK levels is U/L. The rows in the data set correspond to the primary studies.
#'
#' @docType data
#'
#' @format A data frame with 18 rows and 13 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the journal name. \cr
#'   \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
#'   \code{q1.g1} \tab first quartile of the CK levels (nonsurvivor group). \cr
#'   \code{med.g1} \tab median CK level (nonsurvivor group). \cr
#'   \code{q3.g1} \tab third quartile of the CK levels (nonsurvivor group).\cr
#'   \code{mean.g1} \tab mean CK level (nonsurvivor group). \cr
#'   \code{sd.g1} \tab standard deviation of the CK levels (nonsurvivor group).\cr
#'   \code{n.g2} \tab number of subjects (survivor group). \cr
#'   \code{q1.g2} \tab first quartile of the CK levels (survivor group). \cr
#'   \code{med.g2} \tab median CK level (survivor group). \cr
#'   \code{q3.g2} \tab third quartile of the CK levels (survivor group).\cr
#'   \code{mean.g2} \tab mean CK level (survivor group). \cr
#'   \code{sd.g2} \tab standard deviation of the CK levels (survivor group).\cr}
#'
#' @references Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
#'
"dat.ck_raw"

#' Example data set: Comparing creatine kinase levels between COVID-19 survivors and nonsurvivors (cleaned version)
#'
#' A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing creatine kinase (CK) levels of COVID-19 infected patients who died and those who survived. The unit of measurement for the CK levels is U/L. The rows in the data set correspond to the primary studies. Compared to the "raw" version (i.e., \code{\link{dat.asat_raw}}), this data set excludes the primary study of Qi et al. (2021) due to its small sample size in the nonsurvivor group.
#'
#' @docType data
#'
#' @format A data frame with 17 rows and 13 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the journal name. \cr
#'   \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
#'   \code{q1.g1} \tab first quartile of the CK levels (nonsurvivor group). \cr
#'   \code{med.g1} \tab median CK level (nonsurvivor group). \cr
#'   \code{q3.g1} \tab third quartile of the CK levels (nonsurvivor group).\cr
#'   \code{mean.g1} \tab mean CK level (nonsurvivor group). \cr
#'   \code{sd.g1} \tab standard deviation of the CK levels (nonsurvivor group).\cr
#'   \code{n.g2} \tab number of subjects (survivor group). \cr
#'   \code{q1.g2} \tab first quartile of the CK levels (survivor group). \cr
#'   \code{med.g2} \tab median CK level (survivor group). \cr
#'   \code{q3.g2} \tab third quartile of the CK levels (survivor group).\cr
#'   \code{mean.g2} \tab mean CK level (survivor group). \cr
#'   \code{sd.g2} \tab standard deviation of the CK levels (survivor group).\cr}
#'
#' @references Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
#' @references Qi X., Liu Y., Wang J., Fallowfield J.A., Wang J., Li X., Shi J., Pan H., Zou S., Zhang H., and others. (2021). Clinical course and risk factors for mortality of COVID-19 patients with pre-existing cirrhosis: A multicentre cohort study, \emph{Gut}, \strong{70}, 433–436.
#'
"dat.ck"

#' Example data set: Patient Health Questionnaire-9 (PHQ-9) scores (raw version)
#'
#' A data set based on a meta-analysis of Patient Health Questionnaire-9 (PHQ-9) scores (Thombs et al. 2014, Levis et al. 2019). This particular data set is from Table S1 and Figure 3 in McGrath et al. (2020); See McGrath et al. (2020) for additional details. The rows in the data set correspond to the primary studies.
#'
#' @docType data
#'
#' @format A data frame with 58 rows and 9 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the year of publication. \cr
#'   \code{n.g1} \tab number of subjects. \cr
#'   \code{min.g1} \tab minimum PHQ-9 score. \cr
#'   \code{q1.g1} \tab first quartile of the PHQ-9 scores. \cr
#'   \code{med.g1} \tab median PHQ-9 score. \cr
#'   \code{q3.g1} \tab third quartile of the PHQ-9 scores.\cr
#'   \code{max.g1} \tab maximum PHQ-9 score. \cr
#'   \code{mean.g1} \tab mean PHQ-9 score. \cr
#'   \code{sd.g1} \tab standard deviation of the PHQ-9 scores.\cr}
#'
#' @references Thombs B.D., Benedetti A., Kloda L.A., et al. (2014). The diagnostic accuracy of the Patient Health Questionnaire-2 (PHQ-2), Patient Health Questionnaire-8 (PHQ-8), and Patient Health Questionnaire-9 (PHQ-9) for detecting major depression: protocol for a systematic review and individual patient data meta-analyses. \emph{Systematic Reviews}. \strong{3}(1):1-16.
#' @references Levis B., Benedetti A., Thombs B.D., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2019). The diagnostic accuracy of the Patient Health Questionnaire-9 (PHQ-9) for detecting major depression. \emph{BMJ}. \strong{365}:l1476.
#' @references McGrath S., Zhao X., Steele R., Thombs B.D., Benedetti A., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2020). Estimating the sample mean and standard deviation from commonly reported quantiles in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{29}(9):2520-2537.
#'
"dat.phq9_raw"


#' Example data set: Patient Health Questionnaire-9 (PHQ-9) scores (processed version)
#'
#' A data set based on a meta-analysis of Patient Health Questionnaire-9 (PHQ-9) scores (Thombs et al. 2014, Levis et al. 2019). This data set was obtained by performing the following data processing items to \code{\link{dat.phq9_raw}}. We randomly selected 14 of the primary studies to report S1 summary statistics, 14 to report S2 summary statistics, 15 to report S3 summary statistics, and 15 to report S4 summary statistics. Since some of the mean-based methods require the sample quantiles to be strictly positive and PHQ-9 scores of 0 were observed in some of the primary studies, we added a value of 0.01 to sample quantiles with a value of 0. Additionally, since some of the mean-based methods do not allow for "ties" in the quantiles (e.g., when the minimum value equals the first quartile value), we added a value of 0.25 to the larger quantile in the event of ties.
#'
#' @docType data
#'
#' @format A data frame with 58 rows and 9 columns:
#' \tabular{ll}{
#'   \code{author} \tab first author of the primary study and the year of publication. \cr
#'   \code{n.g1} \tab number of subjects. \cr
#'   \code{min.g1} \tab minimum PHQ-9 score. \cr
#'   \code{q1.g1} \tab first quartile of the PHQ-9 scores. \cr
#'   \code{med.g1} \tab median PHQ-9 score. \cr
#'   \code{q3.g1} \tab third quartile of the PHQ-9 scores.\cr
#'   \code{max.g1} \tab maximum PHQ-9 score. \cr
#'   \code{mean.g1} \tab mean PHQ-9 score. \cr
#'   \code{sd.g1} \tab standard deviation of the PHQ-9 scores.\cr}
#'
#' @references Thombs B.D., Benedetti A., Kloda L.A., et al. (2014). The diagnostic accuracy of the Patient Health Questionnaire-2 (PHQ-2), Patient Health Questionnaire-8 (PHQ-8), and Patient Health Questionnaire-9 (PHQ-9) for detecting major depression: protocol for a systematic review and individual patient data meta-analyses. \emph{Systematic Reviews}. \strong{3}(1):1-16.
#' @references Levis B., Benedetti A., Thombs B.D., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2019). The diagnostic accuracy of the Patient Health Questionnaire-9 (PHQ-9) for detecting major depression. \emph{BMJ}. \strong{365}:l1476.
#' @references McGrath S., Zhao X., Steele R., Thombs B.D., Benedetti A., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2020). Estimating the sample mean and standard deviation from commonly reported quantiles in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{29}(9):2520-2537.
#'
"dat.phq9"




#' Example data set: Overall survival times in patients with lung cancer
#'
#' A data set based on a meta-analysis comparing overall survival times between individuals randomized to experimental arms and comparator arms in randomized trials for non-small cell lung cancer therapies (Iskander et al. 2024).
#'
#' @docType data
#'
#' @format A data frame with 30 rows and 11 columns:
#' \tabular{ll}{
#'   \code{study} \tab National Clinical Trial (NCT) number of the study. \cr
#'   \code{n.g1} \tab number of subjects (experimental group). \cr
#'   \code{med.g1} \tab median overall survival (experimental group). \cr
#'   \code{med.ci.lb.g1} \tab lower confidence interval bound around the median (experimental group). \cr
#'   \code{med.ci.ub.g1} \tab upper confidence interval bound around the median (experimental group). \cr
#'   \code{med.ci.level.g1} \tab level of the confidence interval (experimental group). \cr
#'   \code{n.g2} \tab number of subjects (comparator group). \cr
#'   \code{med.g2} \tab median overall survival (comparator group). \cr
#'   \code{med.ci.lb.g2} \tab lower confidence interval bound around the median (comparator group). \cr
#'   \code{med.ci.ub.g2} \tab upper confidence interval bound around the median (comparator group). \cr
#'   \code{med.ci.level.g2} \tab level of the confidence interval (comparator group). \cr}
#'
#' @references Iskander, R., Moyer, H., Fergusson, D., McGrath, S., Benedetti, A., and Kimmelman, J. (2024). The benefits and risks of receiving investigational solid tumor drugs in randomized trials: A systematic review and meta-analysis. \emph{Annals of Internal Medicine}. \strong{177}(6)759-767.
#'
"dat.lung"

#' Meta-Analysis via quantile estimation method
#'
#' The function applies the quantile estimation (QE) method (McGrath et al., 2020) to meta-analyze one-group or two-group studies where each study reports one of the following summary measures: \itemize{
#' \item S1: median, minimum and maximum values, and sample size
#' \item S2: median, first and third quartiles, and sample size
#' \item S3: median, minimum and maximum values, first and third quartiles, and sample size
#' \item S4: mean, standard deviation, and sample size.
#'  }
#' For one-group studies, the function estimates the pooled median. For two-group studies, the function estimates the pooled raw difference of medians across groups. The convention used for calculating differences in two-group studies is: value in group 1 minus value in group 2.
#'
#' Letting \eqn{k} denote the number of studies, provide study-specific summary data as vectors of length \eqn{k}. If a study does not report a given summary measure (e.g., the minimum value), give a value of \code{NA} for the position in the relevant vector. If no studies report a given summary measure, a vector of only \code{NA} values need not be provided. See 'Examples' for appropriate use.
#'
#' The sampling variance of the effect size for each study is estimated via the QE method. The default starting values and box constraints of the parameters in the minimization algorithm (\code{\link[estmeansd]{qe.fit}}) are used. After estimating the sampling variances for all studies, studies are meta-analyzed using the \code{\link[metafor]{rma.uni}} function.
#'
#' @param min.g1 vector of study-specific sample minimum values (first group for two-group studies). See 'Details'.
#' @param q1.g1 vector of study-specific sample first quartile values (first group for two-group studies). See 'Details'.
#' @param med.g1 vector of study-specific sample median values (first group for two-group studies). See 'Details'.
#' @param q3.g1 vector of study-specific sample third quartile values (first group for two-group studies). See 'Details'.
#' @param max.g1 vector of study-specific sample maximum values (first group for two-group studies). See 'Details'.
#' @param n.g1 vector of study-specific sample sizes (first group for two-group studies). See 'Details'.
#' @param mean.g1 vector of study-specific sample mean values (first group for two-group studies). See 'Details'.
#' @param sd.g1 vector of study-specific sample standard deviation values (first group for two-group studies). See 'Details'.
#' @param min.g2 vector of study-specific sample minimum values of the second group for two-group studies. See 'Details'.
#' @param q1.g2 vector of study-specific sample first quartile values of the second group for two-group studies. See 'Details'.
#' @param med.g2 vector of study-specific sample median values of the second group for two-group studies. See 'Details'.
#' @param q3.g2 vector of study-specific sample third quartile values of the second group for two-group studies. See 'Details'.
#' @param max.g2 vector of study-specific sample maximum values of the second group for two-group studies. See 'Details'.
#' @param n.g2 vector of study-specific sample sizes of the second group for two-group studies. See 'Details'.
#' @param mean.g2 vector of study-specific sample mean values of the second group for two-group studies. See 'Details'.
#' @param sd.g2 vector of study-specific sample standard deviation values of the second group for two-group studies. See 'Details'.
#' @param single.family logical scalar indicating that for two-group studies, the parametric family of distributions is assumed to be the same across both groups (the default is \code{FALSE}). See 'Details' of \code{\link{qe.study.level}}.
#' @param loc.shift logical scalar indicating that for two-group studies, distributions are assumed to only differ by a location shift (the default is \code{FALSE}). See 'Details' of \code{\link{qe.study.level}}.
#' @param pool_studies logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific effect size estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.
#' @param ... optional arguments for pooling. See documentation of \code{\link[metafor]{rma.uni}}.

#' @return An object of class "rma.uni". See documentation of \code{\link[metafor]{rma.uni}}.
#' @references McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
#'
#' @examples
#' ## Example 1: Meta-analysis of one-group studies
#'
#' ## Storing data
#' ## Note: All 6 studies report S2
#' med.vals <- c(6.1, 5.2, 3.1, 2.8, 4.5)
#' q1.vals <- c(2.0, 1.6, 2.6, 0.9, 3.2)
#' q3.vals <- c(10.2, 13.0, 8.3, 8.2, 9.9)
#' n.vals <- c(100, 92, 221, 81, 42)
#'
#' ## Meta-analyze studies via QE method
#' qe(q1.g1 = q1.vals, med.g1 = med.vals, q3.g1 = q3.vals, n.g1 = n.vals)
#'
#'
#' ## Example 2: Meta-analysis of one-group studies
#'
#' ## Storing data
#' ## Note: Studies 1, 2, 3, and 4 report S1, S2, S3, and S4, respectively
#' min.vals <- c(0.7, NA, 1.1, NA)
#' q1.vals <- c(NA, 5.2, 5.3, NA)
#' med.vals <- c(8.7, 10.7, 11.0, NA)
#' q3.vals <- c(NA, 15.2, 15.3, NA)
#' max.vals <- c(22.2, NA, 24.7, NA)
#' n.vals <- c(52, 34, 57, 90)
#' sd.vals <- c(NA, NA, NA, 4.2)
#' mean.vals <- c(NA, NA, NA, 12.2)
#'
#' ## Meta-analyze studies via QE method
#' qe(min.g1 = min.vals, q1.g1 = q1.vals, med.g1 = med.vals, q3.g1 = q3.vals,
#'    max.g1 = max.vals, n.g1 = n.vals, mean.g1 = mean.vals, sd.g1 = sd.vals)
#'
#'
#' ## Example 3: Meta-analysis of two-group studies
#'
#' ## Storing data
#' ## Note: All 4 studies report S3
#' min.g1 <- c(2.3, 3.2, 1.9, 1.7)
#' q1.g1 <- c(6.0, 7.1, 3.5, 3.8)
#' med.g1 <- c(8.7, 9.5, 5.9, 6.0)
#' q3.g1 <- c(11.3, 13.1, 10.8, 11.0)
#' max.g1 <- c(20.6, 25.3, 17.0, 18.6)
#' n.g1 <- c(53, 49, 66, 75)
#' min.g2 <- c(0.4, 0.9, 0.5, 0.3)
#' q1.g2 <- c(2.5, 3.1, 2.7, 2.3)
#' med.g2 <- c(5.1, 6.2, 4.9, 4.7)
#' q3.g2 <- c(9.6, 10.1, 8.8, 9.2)
#' max.g2 <- c(20.2, 21.4, 18.8, 19.2)
#' n.g2 <- c(50, 45, 60, 73)
#'
#' ## Meta-analyze studies via QE method
#' qe(min.g1 = min.g1, q1.g1 = q1.g1, med.g1 = med.g1, q3.g1 = q3.g1,
#'    max.g1 = max.g1, n.g1 = n.g1, min.g2 = min.g2, q1.g2 = q1.g2,
#'    med.g2 = med.g2, q3.g2 = q3.g2, max.g2 = max.g2, n.g2 = n.g2)
#'
#' @export

qe <- function(min.g1, q1.g1, med.g1, q3.g1, max.g1, n.g1, mean.g1, sd.g1,
               min.g2, q1.g2, med.g2, q3.g2, max.g2, n.g2, mean.g2, sd.g2,
               single.family = FALSE, loc.shift = FALSE, pool_studies = TRUE,
               ...) {
  all.data.args.names <- c("min.g1", "q1.g1", "med.g1", "q3.g1", "max.g1",
                           "n.g1", "mean.g1", "sd.g1", "min.g2", "q1.g2",
                           "med.g2", "q3.g2", "max.g2", "n.g2", "mean.g2",
                           "sd.g2")

  all.args <- as.list(environment())
  data.args <- all.args[names(all.args) %in% all.data.args.names]
  data.args.spec <- data.args[sapply(data.args,
                                     function(x) class(x) == "numeric" |
                                       class(x) == "integer")]
  data.args.unspec.names <- all.data.args.names[!(all.data.args.names
                                                  %in% names(data.args.spec))]

  if (length(unique(lengths(data.args.spec))) != 1) {
    stop("All vectors of summary data must have same length")
  }

  df <- as.data.frame(data.args.spec)
  df[, data.args.unspec.names] <- rep(NA, nrow(df))
  na.row.indicator <- apply(df, 1, function(x) all(is.na(x)))
  if (any(na.row.indicator)) {
    df <- df[!na.row.indicator, ]
  }

  res <- mapply(qe.study.level, df$min.g1, df$q1.g1, df$med.g1, df$q3.g1,
                df$max.g1, df$n.g1, df$mean.g1, df$sd.g1, df$min.g2, df$q1.g2,
                df$med.g2, df$q3.g2, df$max.g2, df$n.g2, df$mean.g2, df$sd.g2,
                single.family, loc.shift)

  study.types <- unlist(res["study.type", ])

  if (length(unique(study.types)) != 1) {
    stop("All studies must have the same study type (i.e.,
         all studies must be one-group or all studies must be two-group)")
  }

  if (pool_studies){
    output <- metafor::rma.uni(yi = unlist(res["effect.size", ]),
                               vi = unlist(res["var", ]), ...)
  } else {
    output <- list(yi = unlist(res["effect.size", ]),
                   sei = sqrt(unlist(res["var", ])))
  }

  return(output)
}

#' Study-Level application of quantile estimation method
#'
#' This function estimates the asymptotic sampling variance of either the (estimated) median or the (estimated) difference of medians for a primary study that reports one of the following summary measures: \itemize{
#' \item S1: median, minimum and maximum values, and sample size
#' \item S2: median, first and third quartiles, and sample size
#' \item S3: median, minimum and maximum values, first and third quartiles, and sample size
#' \item S4: mean, standard deviation, and sample size.
#'  }.
#'
#' In order to estimate the asymptotic sampling variance of the median (in S1, S2, or S3), one must have an estimate of the probability density function of the outcome evaluated at the population median. The \code{\link[estmeansd]{qe.fit}} function is applied to estimate the outcome distribution.
#'
#' For two-group studies studies, one may assume that the outcome in both groups follows the same parametric family of distributions. In this case, distribution selection for the QE method is applied as follows. The \code{\link[estmeansd]{qe.fit}} function is applied to fit the candidate distributions of each group separately. However, for each candidate distribution, the objective function evaluated at the fitting parameters are summed over the two groups. The parametric family of distributions with the smallest sum is used as the underlying distribution of the both groups. If \code{single.family} is \code{TRUE}, then \code{selected.dist} is a character string indicating the selected parametric family. If \code{single.family} is \code{FALSE}, then \code{selected.dist} is a vector of length 2 where elements 1 and 2 are character strings of the selected parametric families in groups 1 and 2, respectively.
#'
#' One may also assume for two-group studies that the outcome distributions in the two groups only differ by a location shfit. In this case, a weighted mean (weighted by sample size) of the estimated probability density functions evaluated at the population medians is used to estimate the asymptotic sampling variance of the difference of medians. See McGrath et al. (2020) for further details.
#'
#' When a study provides S4 summary measures, the outcome distribution is assumed to be normal. The sample median is estimated by the sample mean, and its variance is estimated by the sample variance divided by the sample size. In this case, the \code{single.family} and \code{loc.shift} arguments are not used.
#'
#' @param min.g1 numeric value giving the sample minimum (first group for two-group studies).
#' @param q1.g1 numeric value giving the first quartile (first group for two-group studies).
#' @param med.g1 numeric value giving the sample median (first group for two-group studies).
#' @param q3.g1 numeric value giving the sample third quartile (first group for two-group studies).
#' @param max.g1 numeric value giving the sample maximum (first group for two-group studies).
#' @param n.g1 numeric value giving the sample size (first group for two-group studies).
#' @param mean.g1 numeric value giving the sample mean (first group for two-group studies).
#' @param sd.g1 numeric value giving the sample standard deviation (first group for two-group studies).
#' @param min.g2 numeric value giving the sample minimum of the second group for two-group studies.
#' @param q1.g2 numeric value giving the sample first quartile of the second group for two-group studies.
#' @param med.g2 numeric value giving the sample median of the second group for two-group studies.
#' @param q3.g2 numeric value giving the sample third quartile of the second group for two-group studies.
#' @param max.g2 numeric value giving the sample maximum of the second group for two-group studies.
#' @param n.g2 numeric value giving the sample size of the second group for two-group studies.
#' @param mean.g2 numeric value giving the sample mean of the second group for two-group studies.
#' @param sd.g2 numeric value giving the sample standard deviation of the second group for two-group studies.
#' @param single.family logical scalar indicating that for two-group studies, the parametric family of distributions is assumed to be the same across both groups (the default is \code{FALSE}). See 'Details'.
#' @param loc.shift logical scalar indicating that for two-group studies, distributions are assumed to only differ by a location shift (the default is \code{FALSE}). See 'Details'.
#' @param qe.fit.control.g1 optional list of control parameters for \code{\link[estmeansd]{qe.fit}} (first group for two-group studies).
#' @param qe.fit.control.g2 optional list of control parameters for \code{\link[estmeansd]{qe.fit}} of the second group for two-group studies.
#'
#' @return A list with the following components:
#' \item{var}{Estimated sampling variance of the effect size.}
#' \item{effect.size}{Effect size of study.}
#' \item{selected.dist}{Selected outcome distribution(s). See 'Details'.}
#' \item{study.type}{Character string specifying whether one-group or two-group summary data was provided.}
#'
#' @references McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
#'
#' @examples
#' ## Generate S2 summary data
#' set.seed(1)
#' n <- 100
#' x <- stats::rlnorm(n, 2.5, 1)
#' quants <- stats::quantile(x, probs = c(0.25, 0.5, 0.75))
#'
#' ## Estimate sampling variance of the median
#' qe.study.level(q1.g1 = quants[1], med.g1 = quants[2], q3.g1 = quants[3],
#'                n.g1 = n)
#'
#' @export


qe.study.level <- function(min.g1, q1.g1, med.g1, q3.g1, max.g1, n.g1, mean.g1,
                           sd.g1, min.g2, q1.g2, med.g2, q3.g2, max.g2, n.g2,
                           mean.g2, sd.g2, single.family = FALSE,
                           loc.shift = FALSE, qe.fit.control.g1 = list(),
                           qe.fit.control.g2 = list()) {
  if ((missing(min.g2) || is.na(min.g2)) & (missing(q1.g2) || is.na(q1.g2)) &
      (missing(med.g2) || is.na(med.g2)) & (missing(q3.g2) || is.na(q3.g2)) &
      (missing(max.g2) || is.na(max.g2)) & (missing(mean.g2) || is.na(mean.g2))
      & (missing(sd.g2) || is.na(sd.g2))) {
    one.sample <- TRUE
  } else {
    one.sample <- FALSE
  }
  scenario.g1 <- get.scenario(min.g1, q1.g1, med.g1, q3.g1, max.g1, mean.g1,
                              sd.g1)
  if (missing(n.g1) || is.na(n.g1)) {
    stop("Need to specify n.g1")
  }
  if (!one.sample) {
    scenario.g2 <- get.scenario(min.g2, q1.g2, med.g2, q3.g2, max.g2, mean.g2,
                                sd.g2)
    if (missing(n.g2) || is.na(n.g2)) {
      stop("Need to specify n.g2")
    }
  }

  if (scenario.g1 == "S4") {
    effect.size.g1 <- mean.g1
    asymptvar.g1 <- sd.g1^2 / n.g1
    selected.dist.g1 <- "normal"
  } else {
    effect.size.g1 <- med.g1
    fit.g1 <- estmeansd::qe.fit(min.val = min.g1, q1.val = q1.g1,
                                med.val = med.g1, q3.val = q3.g1,
                                max.val = max.g1, n = n.g1,
                                qe.fit.control = qe.fit.control.g1,
                                two.sample.default = TRUE)
    selected.dist.g1 <- names(which.min(fit.g1$values))
    fitted.fm.g1 <- get.fm(fit.g1, selected.dist.g1)
    asymptvar.g1 <- 0.25 * (1 / (fitted.fm.g1^2 * n.g1))
  }
  if (one.sample) {
    effect.size <- effect.size.g1
    asymptvar <- asymptvar.g1
    selected.dist <- selected.dist.g1
  } else {
    if (scenario.g2 == "S4") {
      effect.size.g2 <- mean.g2
      asymptvar.g2 <- sd.g2^2 / n.g2
      selected.dist.g2 <- "normal"
    } else {
      effect.size.g2 <- med.g2
      fit.g2 <- estmeansd::qe.fit(min.val = min.g2, q1.val = q1.g2,
                                  med.val = med.g2, q3.val = q3.g2,
                                  max.val = max.g2, n = n.g2,
                                  qe.fit.control = qe.fit.control.g2,
                                  two.sample.default = TRUE)
      selected.dist.g2 <- names(which.min(fit.g2$values))
      fitted.fm.g2 <- get.fm(fit.g2, selected.dist.g2)
      asymptvar.g2 <- 0.25 * (1 / (fitted.fm.g2^2 * n.g2))
    }
    effect.size <- effect.size.g1 - effect.size.g2
    asymptvar <- asymptvar.g1 + asymptvar.g2
    selected.dist <- c(selected.dist.g1, selected.dist.g2)

    if (scenario.g1 != "S4" & scenario.g2 != "S4" &
        (single.family | loc.shift)){
      if (single.family){
        selected.dist <- names(which.min(fit.g1$values + fit.g2$values))
        fitted.fm.g1 <- get.fm(fit.g1, selected.dist)
        fitted.fm.g2 <- get.fm(fit.g2, selected.dist)
      }
      if (loc.shift) {
        fitted.fm <- stats::weighted.mean(x = c(fitted.fm.g1, fitted.fm.g2),
                                          w = c(n.g1, n.g2))
        asymptvar <- 0.25 / (fitted.fm)^2 * (1 / n.g1 + 1 / n.g2)
      } else {
        asymptvar <- 0.25 * (1 / (fitted.fm.g1^2 * n.g1) +
                               1 / (fitted.fm.g2^2 * n.g2))
      }
    }
  }
  if (one.sample) {
    study.type <- "one-group"
  } else {
    study.type <- "two-group"
  }
  return(list(var = asymptvar, effect.size = effect.size,
              selected.dist = selected.dist, study.type = study.type))
}

get.scenario <- function(min.val, q1.val, med.val, q3.val, max.val, mean.val,
                         sd.val) {
  if (!(missing(min.val) | missing(q1.val) | missing(med.val) | missing(q3.val)
        | missing(max.val))) {
    if (!any(is.na(c(min.val, q1.val, med.val, q3.val, max.val)))) {
      return("S3")
    }
  }
  if (!(missing(q1.val) | missing(med.val) | missing(q3.val))) {
    if (!any(is.na(c(q1.val, med.val, q3.val)))) {
      return("S2")
    }
  }
  if (!(missing(min.val) | missing(med.val) | missing(max.val))) {
    if (!any(is.na(c(min.val, med.val, max.val)))) {
      return("S1")
    }
  }
  if (!(missing(mean.val) | missing(sd.val))) {
    if (!any(is.na(c(mean.val, sd.val)))) {
      return("S4")
    }
  }
  stop("Summary measures not in appropriate form. See documentation for
       appropriate forms.")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cd.R
\name{cd}
\alias{cd}
\title{Meta-Analysis via the confidence distribution approach}
\usage{
cd(
  q1,
  med,
  q3,
  n,
  mean,
  sd,
  med.var,
  med.ci.lb,
  med.ci.ub,
  alpha.1,
  alpha.2,
  pooled.median.ci.level = 0.95,
  method = "RE",
  pool_studies = FALSE
)
}
\arguments{
\item{q1}{vector of study-specific sample first quartile values. See 'Details'.}

\item{med}{vector of study-specific sample median values. See 'Details'.}

\item{q3}{vector of study-specific sample third quartile values. See 'Details'.}

\item{n}{vector of study-specific sample sizes. See 'Details'.}

\item{mean}{vector of study-specific sample mean values. See 'Details'.}

\item{sd}{vector of study-specific sample standard deviation values. See 'Details'.}

\item{med.var}{vector of study-specific estimates of the variance of the median. See 'Details'.}

\item{med.ci.lb}{vector of study-specific lower confidence interval bounds around the medians}

\item{med.ci.ub}{vector of study-specific upper confidence interval bounds around the medians}

\item{alpha.1}{vector of the study-specific \eqn{\alpha_1} values from Ozturk and Balakrishnan (2020)}

\item{alpha.2}{vector of the study-specific \eqn{\alpha_2} values from Ozturk and Balakrishnan (2020)}

\item{pooled.median.ci.level}{optional numeric scalar indicating the desired coverage probability for the pooled median estimate. The default is \code{0.95}.}

\item{method}{character string specifying whether a fixed effect or random effects model is used. The options are \code{FE} (fixed effect) and \code{RE} (random effects). The default is \code{RE}.}

\item{pool_studies}{logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific effect size estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.}
}
\value{
A list with components
\item{pooled.est}{Pooled estimate of the median}
\item{pooled.est.var}{Estimated variance of the pooled median estimator}
\item{pooled.est.ci.lb}{Lower bound of confidence interval for the pooled median}
\item{pooled.est.ci.ub}{Upper bound of confidence interval for the pooled median}
\item{tausq.est}{Estimate of between-study variance (applicable only when \code{method} is set to \code{RE})}
\item{yi}{Study-specific point estimates}
\item{vi}{Study-specific sampling variances}
}
\description{
The function applies the confidence distribution (CD) approach of Ozturk and Balakrishnan (2020) to meta-analyze one-group studies where each study reports one of the following summary measures: \itemize{
\item C1 (and C2): lower and upper bounds of a confidence interval around the median, and coverage probability
\item C3: median, variance estimate of the median, and sample size
\item C4: mean, standard deviation, and sample size.
\item C5: median, first and third quartiles, and sample size
 }
The function estimates the pooled median.
}
\details{
Letting \eqn{k} denote the number of studies, provide study-specific summary data as vectors of length \eqn{k}. If a study does not report a given summary measure (e.g., the minimum value), give a value of \code{NA} for the position in the relevant vector. If no studies report a given summary measure, a vector of only \code{NA} values need not be provided. See 'Examples' for appropriate use.
}
\examples{
## Example 1:
med.vals <- c(6.1, 5.2, 3.1, 2.8, 4.5)
q1.vals <- c(2.0, 1.6, 2.6, 0.9, 3.2)
q3.vals <- c(10.2, 13.0, 8.3, 8.2, 9.9)
n.vals <- c(100, 92, 221, 81, 42)

## Meta-analyze studies via CD method
cd(q1 = q1.vals, med = med.vals, q3 = q3.vals, n = n.vals)


}
\references{
Ozturk, O. and Balakrishnan N. (2020). Meta‐analysis of quantile intervals from different studies with an application to a pulmonary tuberculosis data. \emph{Statistics in Medicine}, \strong{39}, 4519-4537.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dat.lung}
\alias{dat.lung}
\title{Example data set: Overall survival times in patients with lung cancer}
\format{
A data frame with 30 rows and 11 columns:
\tabular{ll}{
  \code{study} \tab National Clinical Trial (NCT) number of the study. \cr
  \code{n.g1} \tab number of subjects (experimental group). \cr
  \code{med.g1} \tab median overall survival (experimental group). \cr
  \code{med.ci.lb.g1} \tab lower confidence interval bound around the median (experimental group). \cr
  \code{med.ci.ub.g1} \tab upper confidence interval bound around the median (experimental group). \cr
  \code{med.ci.level.g1} \tab level of the confidence interval (experimental group). \cr
  \code{n.g2} \tab number of subjects (comparator group). \cr
  \code{med.g2} \tab median overall survival (comparator group). \cr
  \code{med.ci.lb.g2} \tab lower confidence interval bound around the median (comparator group). \cr
  \code{med.ci.ub.g2} \tab upper confidence interval bound around the median (comparator group). \cr
  \code{med.ci.level.g2} \tab level of the confidence interval (comparator group). \cr}
}
\usage{
dat.lung
}
\description{
A data set based on a meta-analysis comparing overall survival times between individuals randomized to experimental arms and comparator arms in randomized trials for non-small cell lung cancer therapies (Iskander et al. 2024).
}
\references{
Iskander, R., Moyer, H., Fergusson, D., McGrath, S., Benedetti, A., and Kimmelman, J. (2024). The benefits and risks of receiving investigational solid tumor drugs in randomized trials: A systematic review and meta-analysis. \emph{Annals of Internal Medicine}. \strong{177}(6)759-767.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qe.R
\name{qe}
\alias{qe}
\title{Meta-Analysis via quantile estimation method}
\usage{
qe(
  min.g1,
  q1.g1,
  med.g1,
  q3.g1,
  max.g1,
  n.g1,
  mean.g1,
  sd.g1,
  min.g2,
  q1.g2,
  med.g2,
  q3.g2,
  max.g2,
  n.g2,
  mean.g2,
  sd.g2,
  single.family = FALSE,
  loc.shift = FALSE,
  pool_studies = TRUE,
  ...
)
}
\arguments{
\item{min.g1}{vector of study-specific sample minimum values (first group for two-group studies). See 'Details'.}

\item{q1.g1}{vector of study-specific sample first quartile values (first group for two-group studies). See 'Details'.}

\item{med.g1}{vector of study-specific sample median values (first group for two-group studies). See 'Details'.}

\item{q3.g1}{vector of study-specific sample third quartile values (first group for two-group studies). See 'Details'.}

\item{max.g1}{vector of study-specific sample maximum values (first group for two-group studies). See 'Details'.}

\item{n.g1}{vector of study-specific sample sizes (first group for two-group studies). See 'Details'.}

\item{mean.g1}{vector of study-specific sample mean values (first group for two-group studies). See 'Details'.}

\item{sd.g1}{vector of study-specific sample standard deviation values (first group for two-group studies). See 'Details'.}

\item{min.g2}{vector of study-specific sample minimum values of the second group for two-group studies. See 'Details'.}

\item{q1.g2}{vector of study-specific sample first quartile values of the second group for two-group studies. See 'Details'.}

\item{med.g2}{vector of study-specific sample median values of the second group for two-group studies. See 'Details'.}

\item{q3.g2}{vector of study-specific sample third quartile values of the second group for two-group studies. See 'Details'.}

\item{max.g2}{vector of study-specific sample maximum values of the second group for two-group studies. See 'Details'.}

\item{n.g2}{vector of study-specific sample sizes of the second group for two-group studies. See 'Details'.}

\item{mean.g2}{vector of study-specific sample mean values of the second group for two-group studies. See 'Details'.}

\item{sd.g2}{vector of study-specific sample standard deviation values of the second group for two-group studies. See 'Details'.}

\item{single.family}{logical scalar indicating that for two-group studies, the parametric family of distributions is assumed to be the same across both groups (the default is \code{FALSE}). See 'Details' of \code{\link{qe.study.level}}.}

\item{loc.shift}{logical scalar indicating that for two-group studies, distributions are assumed to only differ by a location shift (the default is \code{FALSE}). See 'Details' of \code{\link{qe.study.level}}.}

\item{pool_studies}{logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific effect size estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.}

\item{...}{optional arguments for pooling. See documentation of \code{\link[metafor]{rma.uni}}.}
}
\value{
An object of class "rma.uni". See documentation of \code{\link[metafor]{rma.uni}}.
}
\description{
The function applies the quantile estimation (QE) method (McGrath et al., 2020) to meta-analyze one-group or two-group studies where each study reports one of the following summary measures: \itemize{
\item S1: median, minimum and maximum values, and sample size
\item S2: median, first and third quartiles, and sample size
\item S3: median, minimum and maximum values, first and third quartiles, and sample size
\item S4: mean, standard deviation, and sample size.
 }
For one-group studies, the function estimates the pooled median. For two-group studies, the function estimates the pooled raw difference of medians across groups. The convention used for calculating differences in two-group studies is: value in group 1 minus value in group 2.
}
\details{
Letting \eqn{k} denote the number of studies, provide study-specific summary data as vectors of length \eqn{k}. If a study does not report a given summary measure (e.g., the minimum value), give a value of \code{NA} for the position in the relevant vector. If no studies report a given summary measure, a vector of only \code{NA} values need not be provided. See 'Examples' for appropriate use.

The sampling variance of the effect size for each study is estimated via the QE method. The default starting values and box constraints of the parameters in the minimization algorithm (\code{\link[estmeansd]{qe.fit}}) are used. After estimating the sampling variances for all studies, studies are meta-analyzed using the \code{\link[metafor]{rma.uni}} function.
}
\examples{
## Example 1: Meta-analysis of one-group studies

## Storing data
## Note: All 6 studies report S2
med.vals <- c(6.1, 5.2, 3.1, 2.8, 4.5)
q1.vals <- c(2.0, 1.6, 2.6, 0.9, 3.2)
q3.vals <- c(10.2, 13.0, 8.3, 8.2, 9.9)
n.vals <- c(100, 92, 221, 81, 42)

## Meta-analyze studies via QE method
qe(q1.g1 = q1.vals, med.g1 = med.vals, q3.g1 = q3.vals, n.g1 = n.vals)


## Example 2: Meta-analysis of one-group studies

## Storing data
## Note: Studies 1, 2, 3, and 4 report S1, S2, S3, and S4, respectively
min.vals <- c(0.7, NA, 1.1, NA)
q1.vals <- c(NA, 5.2, 5.3, NA)
med.vals <- c(8.7, 10.7, 11.0, NA)
q3.vals <- c(NA, 15.2, 15.3, NA)
max.vals <- c(22.2, NA, 24.7, NA)
n.vals <- c(52, 34, 57, 90)
sd.vals <- c(NA, NA, NA, 4.2)
mean.vals <- c(NA, NA, NA, 12.2)

## Meta-analyze studies via QE method
qe(min.g1 = min.vals, q1.g1 = q1.vals, med.g1 = med.vals, q3.g1 = q3.vals,
   max.g1 = max.vals, n.g1 = n.vals, mean.g1 = mean.vals, sd.g1 = sd.vals)


## Example 3: Meta-analysis of two-group studies

## Storing data
## Note: All 4 studies report S3
min.g1 <- c(2.3, 3.2, 1.9, 1.7)
q1.g1 <- c(6.0, 7.1, 3.5, 3.8)
med.g1 <- c(8.7, 9.5, 5.9, 6.0)
q3.g1 <- c(11.3, 13.1, 10.8, 11.0)
max.g1 <- c(20.6, 25.3, 17.0, 18.6)
n.g1 <- c(53, 49, 66, 75)
min.g2 <- c(0.4, 0.9, 0.5, 0.3)
q1.g2 <- c(2.5, 3.1, 2.7, 2.3)
med.g2 <- c(5.1, 6.2, 4.9, 4.7)
q3.g2 <- c(9.6, 10.1, 8.8, 9.2)
max.g2 <- c(20.2, 21.4, 18.8, 19.2)
n.g2 <- c(50, 45, 60, 73)

## Meta-analyze studies via QE method
qe(min.g1 = min.g1, q1.g1 = q1.g1, med.g1 = med.g1, q3.g1 = q3.g1,
   max.g1 = max.g1, n.g1 = n.g1, min.g2 = min.g2, q1.g2 = q1.g2,
   med.g2 = med.g2, q3.g2 = q3.g2, max.g2 = max.g2, n.g2 = n.g2)

}
\references{
McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qe.study.level.R
\name{qe.study.level}
\alias{qe.study.level}
\title{Study-Level application of quantile estimation method}
\usage{
qe.study.level(
  min.g1,
  q1.g1,
  med.g1,
  q3.g1,
  max.g1,
  n.g1,
  mean.g1,
  sd.g1,
  min.g2,
  q1.g2,
  med.g2,
  q3.g2,
  max.g2,
  n.g2,
  mean.g2,
  sd.g2,
  single.family = FALSE,
  loc.shift = FALSE,
  qe.fit.control.g1 = list(),
  qe.fit.control.g2 = list()
)
}
\arguments{
\item{min.g1}{numeric value giving the sample minimum (first group for two-group studies).}

\item{q1.g1}{numeric value giving the first quartile (first group for two-group studies).}

\item{med.g1}{numeric value giving the sample median (first group for two-group studies).}

\item{q3.g1}{numeric value giving the sample third quartile (first group for two-group studies).}

\item{max.g1}{numeric value giving the sample maximum (first group for two-group studies).}

\item{n.g1}{numeric value giving the sample size (first group for two-group studies).}

\item{mean.g1}{numeric value giving the sample mean (first group for two-group studies).}

\item{sd.g1}{numeric value giving the sample standard deviation (first group for two-group studies).}

\item{min.g2}{numeric value giving the sample minimum of the second group for two-group studies.}

\item{q1.g2}{numeric value giving the sample first quartile of the second group for two-group studies.}

\item{med.g2}{numeric value giving the sample median of the second group for two-group studies.}

\item{q3.g2}{numeric value giving the sample third quartile of the second group for two-group studies.}

\item{max.g2}{numeric value giving the sample maximum of the second group for two-group studies.}

\item{n.g2}{numeric value giving the sample size of the second group for two-group studies.}

\item{mean.g2}{numeric value giving the sample mean of the second group for two-group studies.}

\item{sd.g2}{numeric value giving the sample standard deviation of the second group for two-group studies.}

\item{single.family}{logical scalar indicating that for two-group studies, the parametric family of distributions is assumed to be the same across both groups (the default is \code{FALSE}). See 'Details'.}

\item{loc.shift}{logical scalar indicating that for two-group studies, distributions are assumed to only differ by a location shift (the default is \code{FALSE}). See 'Details'.}

\item{qe.fit.control.g1}{optional list of control parameters for \code{\link[estmeansd]{qe.fit}} (first group for two-group studies).}

\item{qe.fit.control.g2}{optional list of control parameters for \code{\link[estmeansd]{qe.fit}} of the second group for two-group studies.}
}
\value{
A list with the following components:
\item{var}{Estimated sampling variance of the effect size.}
\item{effect.size}{Effect size of study.}
\item{selected.dist}{Selected outcome distribution(s). See 'Details'.}
\item{study.type}{Character string specifying whether one-group or two-group summary data was provided.}
}
\description{
This function estimates the asymptotic sampling variance of either the (estimated) median or the (estimated) difference of medians for a primary study that reports one of the following summary measures: \itemize{
\item S1: median, minimum and maximum values, and sample size
\item S2: median, first and third quartiles, and sample size
\item S3: median, minimum and maximum values, first and third quartiles, and sample size
\item S4: mean, standard deviation, and sample size.
 }.
}
\details{
In order to estimate the asymptotic sampling variance of the median (in S1, S2, or S3), one must have an estimate of the probability density function of the outcome evaluated at the population median. The \code{\link[estmeansd]{qe.fit}} function is applied to estimate the outcome distribution.

For two-group studies studies, one may assume that the outcome in both groups follows the same parametric family of distributions. In this case, distribution selection for the QE method is applied as follows. The \code{\link[estmeansd]{qe.fit}} function is applied to fit the candidate distributions of each group separately. However, for each candidate distribution, the objective function evaluated at the fitting parameters are summed over the two groups. The parametric family of distributions with the smallest sum is used as the underlying distribution of the both groups. If \code{single.family} is \code{TRUE}, then \code{selected.dist} is a character string indicating the selected parametric family. If \code{single.family} is \code{FALSE}, then \code{selected.dist} is a vector of length 2 where elements 1 and 2 are character strings of the selected parametric families in groups 1 and 2, respectively.

One may also assume for two-group studies that the outcome distributions in the two groups only differ by a location shfit. In this case, a weighted mean (weighted by sample size) of the estimated probability density functions evaluated at the population medians is used to estimate the asymptotic sampling variance of the difference of medians. See McGrath et al. (2020) for further details.

When a study provides S4 summary measures, the outcome distribution is assumed to be normal. The sample median is estimated by the sample mean, and its variance is estimated by the sample variance divided by the sample size. In this case, the \code{single.family} and \code{loc.shift} arguments are not used.
}
\examples{
## Generate S2 summary data
set.seed(1)
n <- 100
x <- stats::rlnorm(n, 2.5, 1)
quants <- stats::quantile(x, probs = c(0.25, 0.5, 0.75))

## Estimate sampling variance of the median
qe.study.level(q1.g1 = quants[1], med.g1 = quants[2], q3.g1 = quants[3],
               n.g1 = n)

}
\references{
McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/describe_studies.R
\name{print.describe_studies}
\alias{print.describe_studies}
\title{Print method for "describe_studies" objects}
\usage{
\method{print}{describe_studies}(x, ...)
}
\arguments{
\item{x}{object of class "describe_studies".}

\item{...}{other arguments.}
}
\value{
No value is returned.
}
\description{
Print method for objects of class "describe_studies"
}
\seealso{
\code{\link{describe_studies}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metamedian.R
\name{metamedian}
\alias{metamedian}
\title{Meta-Analysis of the (difference of) medians}
\usage{
metamedian(
  data,
  median_method = "qe",
  single.family = FALSE,
  loc.shift = FALSE,
  norm.approx = TRUE,
  coverage.prob = 0.95,
  cd_method = "RE",
  pool_studies = TRUE,
  ...
)
}
\arguments{
\item{data}{data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
\tabular{ll}{
\code{min.g1} \tab minimum value. \cr
\code{q1.g1} \tab first quartile. \cr
\code{med.g1} \tab median. \cr
\code{q3.g1} \tab third quartile. \cr
\code{max.g1} \tab maximum value. \cr
\code{n.g1} \tab sample size. \cr
\code{mean.g1} \tab sample mean. \cr
\code{sd.g1} \tab sample standard deviation. \cr
\code{med.var.g1} \tab sampling variance of the median (only applicable when \code{median_method="cd"}). \cr
\code{med.ci.lb.g1} \tab lower confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
\code{med.ci.ub.g1} \tab upper confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
\code{alpha.1.g1} \tab \eqn{\alpha_1} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr
\code{alpha.2.g1} \tab \eqn{\alpha_2} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr}
For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{min.g2}, \code{q1.g2}, \code{med.g2}, \code{q3.g2}, \code{max.g2}, \code{n.g2}, \code{mean.g2}, and \code{sd.g2}.}

\item{median_method}{character string specifying the approach used to estimate the study-specific means and their standard errors. The options are
\tabular{ll}{
\code{"mm"} \tab Median of Medians (McGrath et al. 2019) for one-group studies and Median of the Difference of Medians (McGrath et al. 2020) for two group studies. \cr
\code{"wm"} \tab Weighted Median of Medians (McGrath et al. 2019) for one-group studies and Weighted Median of the Difference of Medians (McGrath et al. 2020) for two group studies. \cr
\code{"qe"} \tab Quantile Matching Estimation (McGrath et al. 2020). This approach is applicable for one-group studies or two-group studies. This is the default option. \cr
\code{"cd"} \tab Confidence Distribution (Ozturk and Balakrishnan 2020). This approach is applicable for one-group studies. \cr}}

\item{single.family}{(only applicable when \code{median_method} is set to \code{"qe"}) logical scalar indicating that for two-group studies, the parametric family of distributions is assumed to be the same across both groups. The default is \code{FALSE}. See 'Details' of \code{\link{qe.study.level}}.}

\item{loc.shift}{(only applicable when \code{median_method} is set to \code{"qe"}) logical scalar indicating that for two-group studies, distributions are assumed to only differ by a location shift. The default is \code{FALSE}. See 'Details' of \code{\link{qe.study.level}}.}

\item{norm.approx}{(only applicable when \code{median_method} is set to \code{"mm"} or \code{"wm"}) logical scalar indicating whether normality approximation of the binomial should be used to construct an approximate confidence interval. The default is \code{TRUE}.}

\item{coverage.prob}{(only applicable when \code{median_method} is set to \code{"mm"}, \code{"wm"}, or \code{"cd"}) numeric scalar indicating the desired coverage probability for the pooled (difference of medians) estimate. The default is \code{0.95}.}

\item{cd_method}{(only applicable when \code{median_method} is set to \code{"cd"}) character string specifying whether a fixed effect or random effects model is used. The options are \code{FE} (fixed effect) and \code{RE} (random effects). The default is \code{RE}.}

\item{pool_studies}{logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific outcome measure estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.}

\item{...}{(only applicable when \code{median_method} is set to \code{"qe"}) optional arguments that are passed into the \code{\link[metafor]{rma.uni}} function for pooling. See documentation of \code{\link[metafor]{rma.uni}}.}
}
\value{
an object of class "rma.uni" (when \code{median_method} is set to \code{"qe"}) or a list (when \code{median_method} is set to \code{"mm"}, \code{"wm"}, or \code{"cd"}). For additional details, see \code{\link[metafor]{rma.uni}} (when \code{median_method} is set to \code{"qe"}), \code{\link{pool.med}} (when \code{median_method} is set to \code{"mm"} or \code{"wm"}), and \code{\link{cd}} (when \code{median_method} is set to \code{"cd"}).
}
\description{
This function is a wrapper function for the \code{\link{qe}}, \code{\link{cd}}, and \code{\link{pool.med}} functions. The function implements the methods of McGrath et al. (2019), McGrath et al. (2020), and Ozturk and Balakrishnan (2020) to estimate the pooled (difference of) medians in a meta-analysis. Specifically, the function implements the (weighted) median of medians method, the Ozturk and Balakrishnan (2020) method, and the quantile matching estimation method to meta-analyze one-group studies; the function implements the (weighted) median of the difference of medians method and quantile matching estimation method to meta-analyze two-group studies.
}
\examples{
## Quantile Matching Estimation method
metamedian(data = dat.age, median_method = "qe")

## Median of the Difference of Medians method
metamedian(data = dat.age, median_method = "mm")

## Weighted Median of the Difference of Medians method
metamedian(data = dat.age, median_method = "wm")

}
\references{
McGrath S., Zhao X., Qin Z.Z., Steele R., and Benedetti A. (2019). One-sample aggregate data meta-analysis of medians. \emph{Statistics in Medicine}, \strong{38}, 969-984.

McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.

McGrath S., Zhao X., Ozturk O., Katzenschlager S., Steele R., and Benedetti A. (2024). metamedian: An R package for meta-analyzing studies reporting medians. \emph{Research Synthesis Methods}, \strong{15}, 332-346.

Ozturk O. and Balakrishnan N. (2020). Meta‐analysis of quantile intervals from different studies with an application to a pulmonary tuberculosis data. \emph{Statistics in Medicine}, \strong{39}, 4519-4537.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dat.age}
\alias{dat.age}
\title{Example data set: Comparing the age between COVID-19 survivors and nonsurvivors (cleaned version)}
\format{
A data frame with 51 rows and 13 columns:
\tabular{ll}{
  \code{author} \tab first author of the primary study and the journal name. \cr
  \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
  \code{q1.g1} \tab first quartile of age (nonsurvivor group). \cr
  \code{med.g1} \tab median age (nonsurvivor group). \cr
  \code{q3.g1} \tab third quartile of age (nonsurvivor group).\cr
  \code{mean.g1} \tab mean age (nonsurvivor group). \cr
  \code{sd.g1} \tab standard deviation of age (nonsurvivor group).\cr
  \code{n.g2} \tab number of subjects (survivor group). \cr
  \code{q1.g2} \tab first quartile of age (survivor group). \cr
  \code{med.g2} \tab median age (survivor group). \cr
  \code{q3.g2} \tab third quartile of age (survivor group).\cr
  \code{mean.g2} \tab mean age (survivor group). \cr
  \code{sd.g2} \tab standard deviation of age (survivor group).\cr}
}
\usage{
dat.age
}
\description{
A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing the age of COVID-19 infected patients who died and those who survived. The unit of measurement for the age values is years. The rows in the data set correspond to the primary studies. Compared to the "raw" version (i.e., \code{\link{dat.age_raw}}), this data set excludes the primary study of Qi et al. (2021) due to its small sample size in the nonsurvivor group.
}
\references{
Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.

Qi X., Liu Y., Wang J., Fallowfield J.A., Wang J., Li X., Shi J., Pan H., Zou S., Zhang H., and others. (2021). Clinical course and risk factors for mortality of COVID-19 patients with pre-existing cirrhosis: A multicentre cohort study, \emph{Gut}, \strong{70}, 433–436.
}
\keyword{datasets}

\name{metamedian-defunct}
\alias{metamedian-defunct}
\title{Defunct functions in package \sQuote{metamedian}}

\description{
  These functions are defunct and no longer available.
}

\details{
  The following functions are defunct and no longer available:
  \itemize{
    \item{\code{qe.fit} calls should now be \code{\link[estmeansd]{qe.fit}} (in the \sQuote{estmeansd} package) calls. That is, this function has been moved to the \sQuote{estmeansd} pacakge.}
    \item{Similarly, \code{print.qe.fit} calls should now be \code{\link[estmeansd]{print.qe.fit}} (in the \sQuote{estmeansd} package) calls.}
  }
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dat.phq9}
\alias{dat.phq9}
\title{Example data set: Patient Health Questionnaire-9 (PHQ-9) scores (processed version)}
\format{
A data frame with 58 rows and 9 columns:
\tabular{ll}{
  \code{author} \tab first author of the primary study and the year of publication. \cr
  \code{n.g1} \tab number of subjects. \cr
  \code{min.g1} \tab minimum PHQ-9 score. \cr
  \code{q1.g1} \tab first quartile of the PHQ-9 scores. \cr
  \code{med.g1} \tab median PHQ-9 score. \cr
  \code{q3.g1} \tab third quartile of the PHQ-9 scores.\cr
  \code{max.g1} \tab maximum PHQ-9 score. \cr
  \code{mean.g1} \tab mean PHQ-9 score. \cr
  \code{sd.g1} \tab standard deviation of the PHQ-9 scores.\cr}
}
\usage{
dat.phq9
}
\description{
A data set based on a meta-analysis of Patient Health Questionnaire-9 (PHQ-9) scores (Thombs et al. 2014, Levis et al. 2019). This data set was obtained by performing the following data processing items to \code{\link{dat.phq9_raw}}. We randomly selected 14 of the primary studies to report S1 summary statistics, 14 to report S2 summary statistics, 15 to report S3 summary statistics, and 15 to report S4 summary statistics. Since some of the mean-based methods require the sample quantiles to be strictly positive and PHQ-9 scores of 0 were observed in some of the primary studies, we added a value of 0.01 to sample quantiles with a value of 0. Additionally, since some of the mean-based methods do not allow for "ties" in the quantiles (e.g., when the minimum value equals the first quartile value), we added a value of 0.25 to the larger quantile in the event of ties.
}
\references{
Thombs B.D., Benedetti A., Kloda L.A., et al. (2014). The diagnostic accuracy of the Patient Health Questionnaire-2 (PHQ-2), Patient Health Questionnaire-8 (PHQ-8), and Patient Health Questionnaire-9 (PHQ-9) for detecting major depression: protocol for a systematic review and individual patient data meta-analyses. \emph{Systematic Reviews}. \strong{3}(1):1-16.

Levis B., Benedetti A., Thombs B.D., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2019). The diagnostic accuracy of the Patient Health Questionnaire-9 (PHQ-9) for detecting major depression. \emph{BMJ}. \strong{365}:l1476.

McGrath S., Zhao X., Steele R., Thombs B.D., Benedetti A., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2020). Estimating the sample mean and standard deviation from commonly reported quantiles in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{29}(9):2520-2537.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dat.phq9_raw}
\alias{dat.phq9_raw}
\title{Example data set: Patient Health Questionnaire-9 (PHQ-9) scores (raw version)}
\format{
A data frame with 58 rows and 9 columns:
\tabular{ll}{
  \code{author} \tab first author of the primary study and the year of publication. \cr
  \code{n.g1} \tab number of subjects. \cr
  \code{min.g1} \tab minimum PHQ-9 score. \cr
  \code{q1.g1} \tab first quartile of the PHQ-9 scores. \cr
  \code{med.g1} \tab median PHQ-9 score. \cr
  \code{q3.g1} \tab third quartile of the PHQ-9 scores.\cr
  \code{max.g1} \tab maximum PHQ-9 score. \cr
  \code{mean.g1} \tab mean PHQ-9 score. \cr
  \code{sd.g1} \tab standard deviation of the PHQ-9 scores.\cr}
}
\usage{
dat.phq9_raw
}
\description{
A data set based on a meta-analysis of Patient Health Questionnaire-9 (PHQ-9) scores (Thombs et al. 2014, Levis et al. 2019). This particular data set is from Table S1 and Figure 3 in McGrath et al. (2020); See McGrath et al. (2020) for additional details. The rows in the data set correspond to the primary studies.
}
\references{
Thombs B.D., Benedetti A., Kloda L.A., et al. (2014). The diagnostic accuracy of the Patient Health Questionnaire-2 (PHQ-2), Patient Health Questionnaire-8 (PHQ-8), and Patient Health Questionnaire-9 (PHQ-9) for detecting major depression: protocol for a systematic review and individual patient data meta-analyses. \emph{Systematic Reviews}. \strong{3}(1):1-16.

Levis B., Benedetti A., Thombs B.D., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2019). The diagnostic accuracy of the Patient Health Questionnaire-9 (PHQ-9) for detecting major depression. \emph{BMJ}. \strong{365}:l1476.

McGrath S., Zhao X., Steele R., Thombs B.D., Benedetti A., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2020). Estimating the sample mean and standard deviation from commonly reported quantiles in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{29}(9):2520-2537.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metamean.R
\name{metamean}
\alias{metamean}
\title{Meta-Analysis of the (difference of) means}
\usage{
metamean(
  data,
  mean_method = "mln",
  se_method,
  sd_method,
  nboot = 1000,
  pool_studies = TRUE,
  ...
)
}
\arguments{
\item{data}{data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
\tabular{ll}{
\code{min.g1} \tab minimum value. \cr
\code{q1.g1} \tab first quartile. \cr
\code{med.g1} \tab median. \cr
\code{q3.g1} \tab third quartile. \cr
\code{max.g1} \tab maximum value. \cr
\code{n.g1} \tab sample size. \cr
\code{mean.g1} \tab sample mean. \cr
\code{sd.g1} \tab sample standard deviation. \cr}
For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{min.g2}, \code{q1.g2}, \code{med.g2}, \code{q3.g2}, \code{max.g2}, \code{n.g2}, \code{mean.g2}, and \code{sd.g2}.}

\item{mean_method}{character string specifying the approach used to estimate the study-specific means. The options are the following:
\tabular{ll}{
\code{'hozo/wan/bland'} \tab Method recommended by Wan et al. (2014), i.e., the method of Hozo et al. (2005) in scenario S1, method of Wan et al. (2014) in scenario S2, and method of Bland (2015) in scenario S3. \cr
\code{'luo'} \tab Method of Luo et al. (2018). \cr
\code{'shi_lognormal'} \tab Method of Shi et al. (2020b). \cr
\code{'qe'} \tab Quantile Matching Estimation method (McGrath et al. 2020). \cr
\code{'bc'} \tab Box-Cox method (McGrath et al. 2020). \cr
\code{'mln'} \tab Method for Unknown Non-Normal Distributions (Cai et al. 2021). \cr
\code{'yang'} \tab Method of Yang et al. (2022) under the assumption of normality. \cr}}

\item{se_method}{character string specifying the approach used to estimate the standard errors of the study-specific means estimators in scenarios S1, S2, and S3. The options are the following:
\tabular{ll}{
\code{'naive'} \tab Uses the estimated standard deviation divided by the square root of the sample size as the estimate of the standard error of the mean estimator. This is the default option when \code{mean_method} is set to \code{'wan'}, \code{'luo'}, or \code{'shi_lognormal'}. The approach used to estimate the standard deviation is specified by the \code{sd_method} argument. \cr
\code{'bootstrap'} \tab Parametric bootstrap approach described by McGrath et al. (2023). This option is only available (and is the default option) when \code{mean_method} is set to \code{'qe'}, \code{'bc'}, or \code{'mln'}. \cr
\code{'plugin'} \tab Uses the analytically derived standard error of the mean estimator, and plugs in the estimated standard deviation in place of the distributional standard deviation. This option is only available (and is the default option) when \code{mean_method} is set to \code{'yang'}. \cr}}

\item{sd_method}{character string specifying the approach used to estimate the study-specific standard deviations when applying the naive standard error estimator (if applicable). The options are the following:
\tabular{ll}{
\code{'wan'} \tab Method of Wan et al. (2014). This is the default option when \code{mean_method} is set to \code{'hozo/wan/bland'}.\cr
\code{'wan/shi_normal'} \tab Method recommended by Shi et al. (2020a), i.e., the method of Wan et al. (2014) in scenarios S1 and S2 and the method of Shi et al. (2020a) in scenario S3. This is the default option when \code{mean_method} is set to \code{'luo'}. \cr
\code{'shi_lognormal'} \tab Method of Shi et al. (2020b). This is the default option when \code{mean_method} is set to \code{'shi_lognormal'}. \cr
\code{'qe'} \tab Quantile Matching Estimation method (McGrath et al. 2020). This is the default option when \code{mean_method} is set to \code{'qe'}. \cr
\code{'bc'} \tab Box-Cox method (McGrath et al. 2020). This is the default option when \code{mean_method} is set to \code{'bc'}. \cr
\code{'mln'} \tab Method for Unknown Non-Normal Distributions (Cai et al. 2021). This is the default option when \code{mean_method} is set to \code{'mln'}. \cr
\code{'yang'} \tab Method of Yang et al. (2022) under the assumption of normality. This is the default option when \code{mean_method} is set to \code{'yang'}. \cr}}

\item{nboot}{integer specifying the number of bootstrap samples to use when using parametric bootstrap to estimate the study-specific standard errors in scenarios S1, S2, and S3. The default is \code{1000}.}

\item{pool_studies}{logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific outcome measure estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.}

\item{...}{optional arguments that are passed into the \code{\link[metafor]{rma.uni}} function for pooling. See documentation of \code{\link[metafor]{rma.uni}}.}
}
\value{
an object of class "rma.uni". See documentation of \code{\link[metafor]{rma.uni}}.
}
\description{
The function meta-analyzes one-group or two-group studies where each study reports one of the following summary measures: \itemize{
\item S1: median, minimum and maximum values, and sample size
\item S2: median, first and third quartiles, and sample size
\item S3: median, minimum and maximum values, first and third quartiles, and sample size
\item S4: mean, standard deviation, and sample size.
 }
This function estimates the study-specific means and their standard errors from the S1, S2, S3, or S4 summary data. When studies report S1, S2, or S3 summary data, a number of approaches can be applied to estimate the study-specific means and their standard errors. Then, this function estimates the pooled mean (for one-group studies) or the pooled difference of means (for two-group studies) based on the standard inverse variance method via the \code{\link[metafor]{rma.uni}} function. The convention used for calculating differences of means in two-group studies is: mean in group 1 minus mean in group 2.
}
\examples{
\donttest{

## Method for Unknown Non-Normal Distributions
metamean(data = dat.age, mean_method = "mln", se_method = "bootstrap", nboot = 50)

## Box-Cox method
metamean(data = dat.age, mean_method = "bc", se_method = "bootstrap", nboot = 50)

## Quantile Matching Estimation method
metamean(data = dat.age, mean_method = "qe", se_method = "bootstrap", nboot = 50)

}

}
\references{
Bland M. (2015). Estimating mean and standard deviation from the sample size, three quartiles, minimum, and maximum. \emph{International Journal of Statistics in Medical Research}. \strong{4}(1):57-64.

Cai S., Zhou J., and Pan J. (2021). Estimating the sample mean and standard deviation from order statistics and sample size in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{30}(12):2701-2719.

Hozo S.P., Djulbegovic B., and Hozo I. (2005). Estimating the mean and variance from the median, range, and the size of a sample. \emph{BMC Medical Research Methodology}. \strong{5}(1):1-10.

Luo D., Wan X., Liu J., and Tong T. (2016). Optimally estimating the sample mean from the sample size, median, mid-range, and/or mid-quartile range. \emph{Statistical Methods in Medical Research}. \strong{27}(6):1785-805.

McGrath S., Zhao X., Steele R., Thombs B.D., Benedetti A., and the DEPRESsion Screening Data (DEPRESSD) Collaboration. (2020). Estimating the sample mean and standard deviation from commonly reported quantiles in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{29}(9):2520-2537.

McGrath S., Katzenschlager S., Zimmer A.J., Seitel A., Steele R., and Benedetti A. (2023). Standard error estimation in meta-analysis of studies reporting medians. \emph{Statistical Methods in Medical Research}. \strong{32}(2):373-388.

McGrath S., Zhao X., Ozturk O., Katzenschlager S., Steele R., and Benedetti A. (2024). metamedian: An R package for meta-analyzing studies reporting medians. \emph{Research Synthesis Methods}. \strong{15}(2):332-346.

Shi J., Luo D., Weng H., Zeng X.T., Lin L., Chu H., and Tong T. (2020a). Optimally estimating the sample standard deviation from the five-number summary. \emph{Research synthesis methods}. \strong{11}(5):641-654.

Shi J., Tong T., Wang Y., and Genton M.G. (2020b). Estimating the mean and variance from the five-number summary of a log-normal distribution. \emph{Statistics and Its Interface}. \strong{13}(4):519-531.

Wan X., Wang W., Liu J., and Tong T. (2014). Estimating the sample mean and standard deviation from the sample size, median, range and/or interquartile range. \emph{BMC Medical Research Methodology}. \strong{14}(1):1-13.

Yang X., Hutson A.D., and Wang D. (2022). A generalized BLUE approach for combining location and scale information in a meta-analysis. \emph{Journal of Applied Statistics}. \strong{49}(15):3846-3867.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dat.ck_raw}
\alias{dat.ck_raw}
\title{Example data set: Comparing creatine kinase transaminase levels between COVID-19 survivors and nonsurvivors (raw version)}
\format{
A data frame with 18 rows and 13 columns:
\tabular{ll}{
  \code{author} \tab first author of the primary study and the journal name. \cr
  \code{n.g1} \tab number of subjects (nonsurvivor group). \cr
  \code{q1.g1} \tab first quartile of the CK levels (nonsurvivor group). \cr
  \code{med.g1} \tab median CK level (nonsurvivor group). \cr
  \code{q3.g1} \tab third quartile of the CK levels (nonsurvivor group).\cr
  \code{mean.g1} \tab mean CK level (nonsurvivor group). \cr
  \code{sd.g1} \tab standard deviation of the CK levels (nonsurvivor group).\cr
  \code{n.g2} \tab number of subjects (survivor group). \cr
  \code{q1.g2} \tab first quartile of the CK levels (survivor group). \cr
  \code{med.g2} \tab median CK level (survivor group). \cr
  \code{q3.g2} \tab third quartile of the CK levels (survivor group).\cr
  \code{mean.g2} \tab mean CK level (survivor group). \cr
  \code{sd.g2} \tab standard deviation of the CK levels (survivor group).\cr}
}
\usage{
dat.ck_raw
}
\description{
A data set from the meta-analysis of Katzenschlager et al. (2021). Specifically, this data set corresponds to the meta-analysis comparing creatine kinase (CK) levels of COVID-19 infected patients who died and those who survived. The unit of measurement for the CK levels is U/L. The rows in the data set correspond to the primary studies.
}
\references{
Katzenschlager S., Zimmer A.J., Gottschalk C., Grafeneder J., Seitel A., Maier-Hein L., Benedetti A., Larmann J., Weigand M.A., McGrath S., and Denkinger C.M. (2021). Can we predict the severe course of COVID-19 - A systematic review and meta-analysis of indicators of clinical outcome? \emph{PLOS One}, \strong{16}, e0255154.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/describe_studies.R
\name{describe_studies}
\alias{describe_studies}
\title{Descriptive statistics for meta-analyzing studies reporting sample medians}
\usage{
describe_studies(data, method = "qe", group_labels = c("Group 1", "Group 2"))
}
\arguments{
\item{data}{data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
\tabular{ll}{
\code{min.g1} \tab minimum value. \cr
\code{q1.g1} \tab first quartile. \cr
\code{med.g1} \tab median. \cr
\code{q3.g1} \tab third quartile. \cr
\code{max.g1} \tab maximum value. \cr
\code{n.g1} \tab sample size. \cr
\code{mean.g1} \tab sample mean. \cr
\code{sd.g1} \tab sample standard deviation. \cr
\code{med.var.g1} \tab sampling variance of the median (only applicable when \code{median_method="cd"}). \cr
\code{med.ci.lb.g1} \tab lower confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
\code{med.ci.ub.g1} \tab upper confidence interval bound around the median (only applicable when \code{median_method="cd"}). \cr
\code{alpha.1.g1} \tab \eqn{\alpha_1} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr
\code{alpha.2.g1} \tab \eqn{\alpha_2} values from Ozturk and Balakrishnan (2020) (only applicable when \code{median_method="cd"}). \cr}
For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{min.g2}, \code{q1.g2}, \code{med.g2}, \code{q3.g2}, \code{max.g2}, \code{n.g2}, \code{mean.g2}, and \code{sd.g2}.}

\item{method}{character string specifying the sets of summary statistics to consider. If this argument is set to \code{"cd"}, the summary statistics for the CD method (see C1/C2, C3, C4, C5 in \code{\link{cd}}) are considered. Otherwise, the S1, S2, S3, and S4 summary statistics described in \code{\link{qe}} are considered.}

\item{group_labels}{vector of character strings specifying the names corresponding to groups 1 and 2, respectively. This argument is only applicable when the meta-analysis consists of two-group studies. By default, this argument is set to \code{c('Group 1', 'Group 2')}.}
}
\value{
an object of class \code{"describe_studies"}. The object is a list with the following components:
\item{description}{data frame containing the results of the descriptive analyses.}
\item{bowley_g1}{vector containing the study-specific Bowley skewness values in group 1.}
\item{bowley_g2}{vector containing the study-specific Bowley skewness values in group 2.}
\item{skew_test_g1}{data frame containing the results of the skewness test of Shi et al. (2023) based on the group 1 data. The data frame contains the test statistic values, critical values at the 0.05 level, and indicators of statistical significance at the 0.05 level.}
\item{skew_test_g2}{data frame containing the results of the skewness test of Shi et al. (2023) based on the group 2 data. The data frame contains the test statistic values, critical values at the 0.05 level, and indicators of statistical significance at the 0.05 level.}
The results are printed with the \code{\link{print.describe_studies}} function.
}
\description{
This function performs some descriptive analyses for meta-analyzing studies reporting sample medians. Specifically, this function describes: (i) the number of studies reporting various summary statistics, (ii) the Bowley skewness (Bowley, 1901) in the primary studies, and (iii) the results of a skewness test (Shi et al., 2023) applied to the summary statistics reported in the primary studies.
}
\examples{
describe_studies(data = dat.age, group_labels = c("Nonsurvivors", "Survivors"))

}
\references{
Bowley, A.L. (1901). Elements of Statistics. London: P.S. King & Son.

McGrath S., Zhao X., Ozturk O., Katzenschlager S., Steele R., and Benedetti A. (2024). metamedian: An R package for meta-analyzing studies reporting medians. \emph{Research Synthesis Methods}. \strong{15}(2):332-346.

Shi J., Luo D., Wan X., Yue L., Liu J., Bian Z., Tong T. (2023). Detecting the skewness of data from the five-number summary and its application in meta-analysis. \emph{Statistical Methods in Medical Research}. \strong{32}(7):1338-1360.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pool.med.R
\name{pool.med}
\alias{pool.med}
\title{Meta-Analysis via median of (the difference of) medians method}
\usage{
pool.med(yi, wi, norm.approx = TRUE, coverage.prob = 0.95)
}
\arguments{
\item{yi}{vector of the study-specific effect sizes (e.g., the medians or the difference of medians)}

\item{wi}{optional vector of positive, study-specific weights (e.g., sample sizes)}

\item{norm.approx}{optional logical scalar indicating whether normality approximation of the binomial should be used to construct an approximate confidence interval (the default is \code{TRUE}).}

\item{coverage.prob}{optional numeric scalar indicating the desired coverage probability (the default is \code{0.95}).}
}
\value{
A list with components
\item{pooled.est}{Pooled estimate}
\item{ci.lb}{Lower bound of confidence interval}
\item{ci.ub}{Upper bound of confidence interval}
\item{cov.level}{Theoretical coverage of the confidence interval around the pooled estimate. When \code{norm.approx} is set to \code{TRUE}, the theoretical coverage is the same as the value specified by \code{coverage.prob}. When \code{norm.approx} is set to \code{FALSE}, the theoretical coverage is set to the smallest possible value greater than the value specified by \code{coverage.prob}.}
}
\description{
This function meta-analyzes the study-specific effect sizes by applying the (weighted) median of medians method (McGrath et al., 2019) in one-sample contexts and the (weighted) median of the difference of median method (McGrath et al., 2020) in two-sample contexts.
}
\details{
For one-group studies, authors may report the sample median or mean. If these measures are supplied for \code{yi} and weights are not provided for \code{wi}, the function implements the median of medians (MM) method (McGrath et al., 2019).

For two-group studies, authors may report the difference of medians or the difference of means across both groups. If these measures are supplied for \code{yi} and weights are not provided for \code{wi}, the function implements the median of the difference of medians (MDM) method (McGrath et al., 2020).

Analogous weighted versions of the MM and MDM methods can be applied when study-specific sample sizes are provided for \code{wi}.

The confidence interval around the pooled estimate is constructed by inverting the sign test.
}
\examples{
## Storing data (study-specific difference of medians)
yi <- c(5.23, 3.10, 0.50, 0.78, 3.48, 0.59, 2.20, 5.06, 4.00)

## Meta-analysis of the difference of medians
pool.med(yi)

}
\references{
McGrath S., Zhao X., Qin Z.Z., Steele R., and Benedetti A. (2019). One-sample aggregate data meta-analysis of medians. \emph{Statistics in Medicine}, \strong{38}, 969-984.

McGrath S., Sohn H., Steele R., and Benedetti A. (2020). Meta-analysis of the difference of medians. \emph{Biometrical Journal}, \strong{62}, 69-98.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metamedian_survival.R
\name{metamedian_survival}
\alias{metamedian_survival}
\title{Meta-Analysis of the median survival times}
\usage{
metamedian_survival(data, estimand, pool_studies = TRUE, ...)
}
\arguments{
\item{data}{data frame containing the study-specific summary data. For one-group studies, this data frame can contain the following columns:
\tabular{ll}{
\code{med.g1} \tab median. \cr
\code{med.ci.lb.g1} \tab lower confidence interval bound around the median. \cr
\code{med.ci.ub.g1} \tab upper confidence interval bound around the median. \cr
\code{med.ci.level.g1} \tab level of the confidence interval}
For two group studies, this data frame can also contain the following columns for the summary data of the second group: \code{med.g2}, \code{med.ci.lb.g2}, \code{med.ci.ub.g2}, and \code{med.ci.level.g2}.}

\item{estimand}{character string specifying the estimand in the meta-analysis. The options are \code{"median_g1"} (median in group 1), \code{"median_g2"} (median in group 2), \code{"difference_median"} (difference of medians across groups), and \code{"ratio_median"} (ratio of medians across groups).}

\item{pool_studies}{logical scalar specifying whether to meta-analyze the studies. If this argument is set to \code{FALSE}, function will not meta-analyze the studies and will return a list with components \code{yi} containing the study-specific outcome measure estimates and \code{sei} containing the study-specific within-study standard error estimates. The default is \code{TRUE}.}

\item{...}{optional arguments that are passed into the \code{\link[metafor]{rma.uni}} function for pooling. See documentation of \code{\link[metafor]{rma.uni}}.}
}
\value{
an object of class "rma.uni". For additional details, see \code{\link[metafor]{rma.uni}}.
}
\description{
This function implements the Wald approximation-based approach described by McGrath et al. (2026) to meta-analyze median survival times. This approach considers that each study reports a Kaplan-Meier estimate of median survival in (each group of) each study along with confidence intervals. This approach performs an inverse-variance weighted meta-analysis of the median survival time (for one group studies) or the difference/ratio of median survival times between groups (for two-group studies). The within-study standard errors are estimated by assuming the confidence intervals around the median survival estimates are Wald-type intervals.
}
\examples{
## Median survival in the comparator group
metamedian_survival(data = dat.lung, estimand = "median_g2")

## Difference of median survival
metamedian_survival(data = dat.lung, estimand = "difference_median")

## Ratio of median survival (logarithm scale)
metamedian_survival(data = dat.lung, estimand = "ratio_median")

}
\references{
McGrath S., Yang C.H., Kimmelman J., Ozturk O., Steele R., and Benedetti A. (2026). Meta-analysis of median survival times with inverse-variance weighting. \emph{Statistics in Medicine}, \strong{45}, e70533.
}
